from ApiMethod import ApiMethod

class Account(ApiMethod):
    def __init__(self, access_token, v, session, calls_per_second):
        super(Account, self).__init__(access_token, v, session, calls_per_second)
        self._base_method = 'account.'

    def ban(self, owner_id: str = None) -> dict:
        """
        Добавляет пользователя или группу в черный список.

        :param owner_id: идентификатор пользователя или сообщества, которое будет добавлено в черный список.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'ban'
        return self._call(method_name, params)

    def changePassword(self, restore_sid: str = None, change_password_hash: str = None, old_password: str = None,
                       new_password: str = None) -> dict:
        """
        Позволяет сменить пароль пользователя после успешного восстановления доступа к аккаунту через СМС, используя
        метод auth.restore.

        :param restore_sid: идентификатор сессии, полученный при восстановлении доступа используя метод
            auth.restore. (В случае если пароль меняется сразу после восстановления доступа)
        :param change_password_hash: хэш, полученный при успешной OAuth авторизации по коду полученному по СМС (В
            случае если пароль меняется сразу после восстановления доступа)
        :param old_password: текущий пароль пользователя.
        :param new_password: новый пароль, который будет установлен в качестве текущего.

        :return: Возвращает объект с единственным полем token, содержащим новый токен
        """

        params = locals()
        method_name = self._base_method + 'changePassword'
        return self._call(method_name, params)

    def getActiveOffers(self, offset: str = None, count: str = None) -> dict:
        """
        Возвращает список активных рекламных предложений (офферов), выполнив которые пользователь сможет получить
        соответствующее количество голосов на свой счёт внутри приложения.

        :param offset: смещение, необходимое для выборки определенного подмножества офферов.
        :param count: количество офферов, которое необходимо получить

        :return: Возвращает массив, состоящий из общего количества старгетированных на текущего пользователя
            специальных предложений (первый элемент), и списка объектов с информацией о предложениях.  В случае, если
            на пользователя не старгетировано ни одного специального предложения, массив будет содержать элемент 0
            (количество специальных предложений)
        """

        params = locals()
        method_name = self._base_method + 'getActiveOffers'
        return self._call(method_name, params)

    def getAppPermissions(self, user_id: str = None) -> dict:
        """
        Получает настройки текущего пользователя в данном приложении.

        :param user_id: идентификатор пользователя, информацию о настройках которого необходимо получить. По
            умолчанию — текущий пользователь.

        :return: После успешного выполнения возвращает битовую маску настроек текущего пользователя в данном
            приложении.   Пример Если Вы хотите получить права на Доступ к друзьям и Доступ к статусам пользователя,
            то Ваша битовая маска будет равна: 2 + 1024 = 1026.  Если, имея битовую маску 1026, Вы хотите проверить,
            имеет ли она доступ к друзьям — Вы можете сделать 1026 & 2. Например alert(1026 & 2);  см. Список
            возможных настроек прав доступ
        """

        params = locals()
        method_name = self._base_method + 'getAppPermissions'
        return self._call(method_name, params)

    def getBanned(self, offset: str = None, count: str = None) -> dict:
        """
        Возвращает список пользователей, находящихся в черном списке.

        :param offset: смещение, необходимое для выборки определенного подмножества черного списка.
        :param count: количество объектов, информацию о которых необходимо вернуть.

        :return: После успешного выполнения возвращает объект, содержащий число результатов в поле count и массив
            объектов, описывающих пользователей в поле items
        """

        params = locals()
        method_name = self._base_method + 'getBanned'
        return self._call(method_name, params)

    def getCounters(self, filter: str = None) -> dict:
        """
        Возвращает ненулевые значения счетчиков пользователя.

        :param filter: счетчики, информацию о которых нужно вернуть. Может включать следующие значения:   friends
            — новые заявки в друзья;  friends_suggestions — предлагаемые друзья;  messages — новые сообщения;  photos
            — новые отметки на фотографиях;  videos — новые отметки на видеозаписях;  gifts — подарки;  events —
            события;  groups — сообщества;  notifications — ответы;  sdk — запросы в мобильных играх;  app_requests —
            уведомления от приложений.  friends_recommendations — рекомендации друзей.

        :return: Возвращает объект, который может содержать поля friends, messages, photos, videos, notes, gifts,
            events, groups, notifications, sdk, app_requests, friends_recommendations со значением счетчиков
            (integer)
        """

        params = locals()
        method_name = self._base_method + 'getCounters'
        return self._call(method_name, params)

    def getInfo(self, fields: str = None) -> dict:
        """
        Возвращает информацию о текущем аккаунте.

        :param fields: список полей, которые необходимо вернуть. Возможные значения:   country  https_required
            own_posts_default  no_wall_replies  intro  lang  По умолчанию будут возвращены все поля.

        :return: Метод возвращает объект, содержащий следующие поля:  country  stringстроковой код страны,
            определенный по IP адресу, с которого сделан запрос. https_required  integer, [0,1]информация о том,
            включено ли безопасное соединение для аккаунта. 1 — включено, 0 — не включено. 2fa_required  integer,
            [0,1]информация о том, включена ли двухфакторная аутентификация для аккаунта. 1 — включена, 0 — не
            включена. own_posts_default  integer, [0,1]информация о том, показываются ли по умолчанию на стене только
            записи пользователя. 1 — да, 0 — нет. no_wall_replies  integer, [0,1]информация о том, отключено ли
            комментирование записей на стене. 1 — да, 0 — нет. intro  integer, [0,1]информация о том, прошел ли
            пользователь обучение по использованию приложения. lang  integerидентификатор текущего языка
            пользователя
        """

        params = locals()
        method_name = self._base_method + 'getInfo'
        return self._call(method_name, params)

    def getProfileInfo(self) -> dict:
        """
        Возвращает информацию о текущем профиле.



        :return: Метод возвращает объект, описывающий профиль пользователя, со следующими полями:  first_name
            string имя пользователя. last_name string фамилия пользователя. maiden_name stringдевичья фамилия
            пользователя (только для женского пола). screen_name stringкороткое имя пользователя (если есть). sex
            integerпол. Возможные значения:   1 — женский;  2 — мужской;  0 — пол не указан. relation integerсемейное
            положение. Возможные значения:   1 — не женат/не замужем;  2 — есть друг/есть подруга;  3 —
            помолвлен/помолвлена;  4 — женат/замужем;  5 — всё сложно;  6 — в активном поиске;  7 — влюблён/влюблена;
            8 — в гражданском браке;  0 — не указано. relation_partner objectобъект пользователя, с которым связано
            семейное положение (если есть). relation_pending  integerпередается 1, если пользователь, указанный в
            relation_partner, не подтвердил отношения. relation_requests arrayсписок объектов пользователей, которые
            указали, что состоят в отношениях с данным пользователем (если есть). bdate stringдата рождения
            пользователя, возвращается в формате D.M.YYYY. bdate_visibility integerвидимость даты рождения. Возможные
            значения:   1 — показывать дату рождения;  2 — показывать только месяц и день;  0 — не показывать дату
            рождения. home_town  stringназвание родного города. country objectстрана. Объект, содержащий поля:   id
            (integer) — идентификатор страны;  title (string) — название страны. city  objectгород. Объект,
            содержащий поля:   id (integer) — идентификатор города;  title (string) — название города. name_request
            objectинформация о заявке на смену имени, если она была подана. Объект, содержащий поля:   id (integer) –
            идентификатор заявки, необходимый для её отмены (только если status равен processing);  status (string) –
            статус заявки. Возможные значения:   processing – заявка рассматривается;  declined – заявка отклонена;
            first_name (string) – имя пользователя, указанное в заявке;  last_name (string) – фамилия пользователя,
            указанная в заявке. status  stringстатус пользователя. phone  stringномер телефона
        """

        params = locals()
        method_name = self._base_method + 'getProfileInfo'
        return self._call(method_name, params)

    def getPushSettings(self, device_id: str = None) -> dict:
        """
        Позволяет получать настройки Push-уведомлений.

        :param device_id: уникальный идентификатор устройства.

        :return: Возвращает объект, содержащий поля:   disabled — отключены ли уведомления.  disabled_until —
            unixtime-значение времени, до которого временно отключены уведомления.  conversations — список,
            содержащий настройки конкретных диалогов, и их количество первым элементом.  settings — объект с
            настройками Push-уведомлений в специальном формате
        """

        params = locals()
        method_name = self._base_method + 'getPushSettings'
        return self._call(method_name, params)

    def registerDevice(self, token: str = None, device_model: str = None, device_year: str = None,
                       device_id: str = None, system_version: str = None, settings: str = None,
                       sandbox: str = None) -> dict:
        """
        Подписывает устройство на базе iOS, Android, Windows Phone или Mac на получение Push-уведомлений.

        :param token: идентификатор устройства, используемый для отправки уведомлений. (для mpns идентификатор
            должен представлять из себя URL для отправки уведомлений).
        :param device_model: cтроковое название модели устройства.
        :param device_year: год устройства.
        :param device_id: уникальный идентификатор устройства.
        :param system_version: строковая версия операционной системы устройства.
        :param settings: сериализованный JSON-объект, описывающий настройки уведомлений в специальном формате.
        :param sandbox: флаг предназначен для iOS устройств. 1 — использовать sandbox сервер для отправки push-
            уведомлений, 0 — не использовать.

        :return: После успешного выполнения возвращает 1.  На iOS и Windows Phone push-уведомления будут
            отображены без какой либо обработки.  На Android будут приходить события в следующем формате
        """

        params = locals()
        method_name = self._base_method + 'registerDevice'
        return self._call(method_name, params)

    def saveProfileInfo(self, first_name: str = None, last_name: str = None, maiden_name: str = None,
                        screen_name: str = None, cancel_request_id: str = None, sex: str = None, relation: str = None,
                        relation_partner_id: str = None, bdate: str = None, bdate_visibility: str = None,
                        home_town: str = None, country_id: str = None, city_id: str = None, status: str = None) -> dict:
        """
        Редактирует информацию текущего профиля.

        :param first_name: имя пользователя. Обязательно с большой буквы.
        :param last_name: фамилия пользователя. Обязательно с большой буквы.
        :param maiden_name: девичья фамилия пользователя (только для женского пола).
        :param screen_name: короткое имя страницы.
        :param cancel_request_id: идентификатор заявки на смену имени, которую необходимо отменить.  Если передан
            этот параметр, все остальные параметры игнорируются.
        :param sex: пол пользователя. Возможные значения:   1 — женский;  2 — мужской.
        :param relation: семейное положение пользователя. Возможные значения:   1 — не женат/не замужем;  2 —
            есть друг/есть подруга;  3 — помолвлен/помолвлена;  4 — женат/замужем;  5 — всё сложно;  6 — в активном
            поиске;  7 — влюблён/влюблена;  8 — в гражданском браке;  0 — не указано.
        :param relation_partner_id: идентификатор пользователя, с которым связано семейное положение.
        :param bdate: дата рождения пользователя в формате DD.MM.YYYY, например "15.11.1984".
        :param bdate_visibility: видимость даты рождения. Возможные значения:   1 — показывать дату рождения;  2
            — показывать только месяц и день;  0 — не показывать дату рождения.
        :param home_town: родной город пользователя.
        :param country_id: идентификатор страны пользователя.
        :param city_id: идентификатор города пользователя.
        :param status: статус пользователя, который также может быть изменен методом status.set

        :return: Метод возвращает объект, содержащий следующие поля:   changed – возвращает 1 — если информация
            была сохранена, 0 — если ни одно из полей не было сохранено.  Если в параметрах передавалось имя или
            фамилия пользователя, в объекте также будет возвращено поле name_request – объект, содержащий информацию
            о заявке на смену имени, со следующими полями:   id – идентификатор заявки, необходимый для её отмены
            (только если status равен processing). Для отмены заявки необходимо вызвать метод account.saveProfileInfo
            с параметром cancel_request_id;  status – статус заявки, возвращаемые значения:   success – имя было
            успешно изменено;  processing – заявка рассматривается;  declined – заявка отклонена;  was_accepted –
            недавно уже была одобрена заявка, повторную заявку можно подать не раньше даты, указанной в поле
            repeat_date;  was_declined – предыдущая заявка была отклонена, повторную заявку можно подать не раньше
            даты, указанной в поле repeat_date;   first_name – имя пользователя, указанное в заявке;  last_name –
            фамилия пользователя, указанная в заявке
        """

        params = locals()
        method_name = self._base_method + 'saveProfileInfo'
        return self._call(method_name, params)

    def setInfo(self, name: str = None, value: str = None) -> dict:
        """
        Позволяет редактировать информацию о текущем аккаунте.

        :param name: имя настройки
        :param value: значение настройки

        :return: В результате успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'setInfo'
        return self._call(method_name, params)

    def setNameInMenu(self, user_id: str = None, name: str = None) -> dict:
        """
        Устанавливает короткое название приложения (до 17 символов), которое выводится пользователю в левом меню.

        :param user_id: идентификатор пользователя.
        :param name: короткое название приложения.

        :return: Возвращает 1 в случае успешной установки короткого названия.  Если пользователь не установил
            приложение в левое меню, метод вернет ошибку 148 (Access to the menu of the user denied). Избежать этой
            ошибки можно с помощью метода account.getAppPermissions
        """

        params = locals()
        method_name = self._base_method + 'setNameInMenu'
        return self._call(method_name, params)

    def setOffline(self) -> dict:
        """
        Помечает текущего пользователя как offline (только в текущем приложении).



        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'setOffline'
        return self._call(method_name, params)

    def setOnline(self, voip: str = None) -> dict:
        """
        Помечает текущего пользователя как online на 5 минут.

        :param voip: возможны ли видеозвонки для данного устройства

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'setOnline'
        return self._call(method_name, params)

    def setPushSettings(self, device_id: str = None, settings: str = None, key: str = None, value: str = None) -> dict:
        """
        Изменяет настройку Push-уведомлений.

        :param device_id: уникальный идентификатор устройства.
        :param settings: сериализованный JSON-объект, описывающий настройки уведомлений в специальном формате.
        :param key: ключ уведомления.
        :param value: новое значение уведомления в специальном формате.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'setPushSettings'
        return self._call(method_name, params)

    def setSilenceMode(self, device_id: str = None, time: str = None, peer_id: str = None, sound: str = None) -> dict:
        """
        Отключает push-уведомления на заданный промежуток времени.

        :param device_id: уникальный идентификатор устройства.
        :param time: время в секундах на которое требуется отключить уведомления, -1 отключить навсегда
        :param peer_id: идентификатор назначения. Для пользователя:  id пользователя.   Для групповой беседы:
            2000000000 + id беседы.   Для сообщества:  -id сообщества.
        :param sound: 1 — включить звук в этом диалоге, 0 — отключить звук (параметр работает, только если в
            peer_id передан идентификатор групповой беседы или пользователя).

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'setSilenceMode'
        return self._call(method_name, params)

    def unban(self, owner_id: str = None) -> dict:
        """
        Удаляет пользователя или группу из черного списка.

        :param owner_id: идентификатор пользователя или группы, которого нужно удалить из черного списка.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'unban'
        return self._call(method_name, params)

    def unregisterDevice(self, device_id: str = None, sandbox: str = None) -> dict:
        """
        Отписывает устройство от Push уведомлений.

        :param device_id: уникальный идентификатор устройства.
        :param sandbox: флаг предназначен для iOS устройств. Возможные значения:   1 — отписать устройство,
            использующего sandbox сервер для отправки push-уведомлений;  0 — отписать устройство, не использующее
            sandbox сервер.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'unregisterDevice'
        return self._call(method_name, params)




from ApiMethod import ApiMethod


class AppWidgets(ApiMethod):
    def __init__(self, access_token, v, session, calls_per_second):
        super(AppWidgets, self).__init__(access_token, v, session, calls_per_second)
        self._base_method = 'appWidgets.'

    def getAppImageUploadServer(self, image_type: str = None) -> dict:
        """
        Позволяет получить адрес для загрузки фотографии в коллекцию приложения для виджетов приложений сообществ.

        :param image_type: тип изображения. Возможные значения:   24x24;  50x50;  160x160;  160x240;  510x128.

        :return: Возвращает объект с единственным полем upload_url, содержащим URL для загрузки изображения.  Для
            загрузки изображения сгенерируйте POST-запрос с файлом в поле image на полученный адрес, а затем вызовите
            метод appWidgets.saveAppImage
        """

        params = locals()
        method_name = self._base_method + 'getAppImageUploadServer'
        return self._call(method_name, params)

    def getAppImages(self) -> dict:
        """
        Позволяет получить коллекцию изображений, загруженных для приложения, в виджетах приложений сообществ.

        :return: Возвращает общее число результатов в поле count (integer) и массив объектов, описывающих
            изображения, в поле items (array).  Каждый объект массива items содержит следующие поля:   id (string) —
            идентификатор изображения. Обратите внимание, идентификаторы изображений для виджетов отличаются от
            обычных фотографий, и НЕ представляют собой сочетание owner_id+"_"+photo_id. Полученный идентификатор
            нужно использовать в коде виджета «как есть».  type (string) — тип изображения. Возможные значения:
            160x160,  160x240,  24x24,  510x128,  50x50.   images (array) — массив копий изображения. Каждый объект в
            массиве содержит следующие поля:   url (string) — URL копии;  width (integer) — ширина в px;  height
            (integer) — высота в px
        """

        params = locals()
        method_name = self._base_method + 'getAppImages'
        return self._call(method_name, params)

    def getGroupImageUploadServer(self) -> dict:
        """
        Позволяет получить адрес для загрузки фотографии в коллекцию сообщества для виджетов приложений сообществ.

        :return: Возвращает объект с единственным полем upload_url, содержащим URL для загрузки изображения.  Для
            загрузки изображения сгенерируйте POST-запрос с файлом в поле image на полученный адрес, а затем вызовите
            метод appWidgets.saveGroupImage
        """

        params = locals()
        method_name = self._base_method + 'getGroupImageUploadServer'
        return self._call(method_name, params)

    def getGroupImages(self) -> dict:
        """
        Позволяет получить коллекцию изображений, загруженных для приложения, в виджетах приложений сообществ.

        :return: Возвращает общее число результатов в поле count (integer) и массив объектов, описывающих
            изображения, в поле items (array).  Каждый объект массива items содержит следующие поля:   id (string) —
            идентификатор изображения. Обратите внимание, идентификаторы изображений для виджетов отличаются от
            обычных фотографий, и НЕ представляют собой сочетание owner_id+"_"+photo_id. Полученный идентификатор
            нужно использовать в коде виджета «как есть».  type (string) — тип изображения. Возможные значения:
            160x160,  160x240,  24x24,  510x128,  50x50.   images (array) — массив копий изображения. Каждый объект в
            массиве содержит следующие поля:   url (string) — URL копии;  width (integer) — ширина в px;  height
            (integer) — высота в px
        """

        params = locals()
        method_name = self._base_method + 'getGroupImages'
        return self._call(method_name, params)

    def getImagesById(self) -> dict:
        """
        Позволяет получить изображение для виджетов приложений сообществ по его идентификатору.

        :return: Возвращает объект, который содержит следующие поля:   id (string) — идентификатор изображения.
            Обратите внимание, идентификаторы изображений для виджетов отличаются от обычных фотографий, и НЕ
            представляют собой сочетание owner_id+"_"+photo_id. Полученный идентификатор нужно использовать в коде
            виджета «как есть».  type (string) — тип изображения. Возможные значения:   160x160,  160x240,  24x24,
            510x128,  50x50.   images (array) — массив копий изображения. Каждый объект в массиве содержит следующие
            поля:   url (string) — URL копии;  width (integer) — ширина в px;  height (integer) — высота в px
        """

        params = locals()
        method_name = self._base_method + 'getImagesById'
        return self._call(method_name, params)

    def saveAppImage(self, hash: str = None, image: str = None) -> dict:
        """
        Позволяет сохранить изображение в коллекцию приложения для виджетов приложений сообществ после загрузки на
        сервер.

        :param hash: параметр hash, полученный после загрузки на сервер.
        :param image: параметр image, полученный после загрузки на сервер.

        :return: Возвращает объект, который содержит следующие поля:   id (string) — идентификатор изображения.
            type (string) — тип изображения. Возможные значения:   160x160,  160x240,  24x24,  510x128,  50x50.
            images (array) — массив копий изображения. Каждый объект в массиве содержит следующие поля:   url
            (string) — URL копии;  width (integer) — ширина в px;  height (integer) — высота в px
        """

        params = locals()
        method_name = self._base_method + 'saveAppImage'
        return self._call(method_name, params)

    def saveGroupImage(self) -> dict:
        """
        Позволяет сохранить изображение в коллекцию сообщества для виджетов приложений сообществ. после загрузки на
        сервер.

        :return: Возвращает объект, который содержит следующие поля:   id (string) — идентификатор изображения.
            type (string) — тип изображения. Возможные значения:   160x160,  160x240,  24x24,  510x128,  50x50.
            images (array) — массив копий изображения. Каждый объект в массиве содержит следующие поля:   url
            (string) — URL копии;  width (integer) — ширина в px;  height (integer) — высота в px
        """

        params = locals()
        method_name = self._base_method + 'saveGroupImage'
        return self._call(method_name, params)

    def update(self) -> dict:
        """
        Позволяет обновить виджет приложения сообщества.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'update'
        return self._call(method_name, params)



from ApiMethod import ApiMethod


class Auth(ApiMethod):
    def __init__(self, access_token, v, session, calls_per_second):
        super(Auth, self).__init__(access_token, v, session, calls_per_second)
        self._base_method = 'auth.'

    def checkPhone(self, phone: str = None, client_id: str = None, client_secret: str = None,
                   auth_by_phone: str = None) -> dict:
        """
        Проверяет правильность введённого номера (возможность его использования для регистрации или авторизации).

        :param phone: номер телефона регистрируемого пользователя.
        :param client_id: идентификатор Вашего приложения.
        :param client_secret: секретный ключ приложения, доступный в разделе редактирования приложения.
        :param auth_by_phone: 1 — проверить правильность номера для авторизации, а не для регистрации нового
            аккаунта. По умолчанию: 0.

        :return: В случае, если номер пользователя является корректным, будет возвращён 1
        """

        params = locals()
        method_name = self._base_method + 'checkPhone'
        return self._call(method_name, params)

    def restore(self, phone: str = None, last_name: str = None) -> dict:
        """
        Позволяет восстановить доступ к аккаунту, используя код, полученный через SMS.  Данный метод доступен только
        приложениям, имеющим доступ к Прямой авторизации.

        :param phone: номер телефона пользователя.
        :param last_name: фамилия пользователя.

        :return: В случае успеха метод возвращает объект содержащий следующие поля:  success – 1;  sid – параметр
            необходимый для получения доступа по коду.  Для завершения восстановления доступа необходимо обратиться
            по адресу: https://oauth.vk.com/token?grant_type=restore_code&client_id={Идентификатор
            приложения}&client_secret={Секретный_ключ}&username={Номер телефона}&scope={Список прав
            доступа}&sid={Параметр, получаемый в данном методе}&code={Код полученный через SMS}  Список параметров:
            grant_type – необходимо передать значение: restore_code;  client_id – Идентификатор приложения;
            client_secret – Секретный ключ;  username – Номер телефона по которому был восстановлен пароль;  scope –
            список прав доступа, разделенных через запятую;  sid – идентификатор сессии, полученный в результате
            выполнения этого метода;  code – код, полученный через SMS.  В результате авторизации через restore_code
            OAuth вернет данные аналогичные обычной авторизации, с дополнительным параметром change_password_hash
            необходимым для метода account.changePassword
        """

        params = locals()
        method_name = self._base_method + 'restore'
        return self._call(method_name, params)



from ApiMethod import ApiMethod


class Notifications(ApiMethod):
    def __init__(self, access_token, v, session, calls_per_second):
        super(Notifications, self).__init__(access_token, v, session, calls_per_second)
        self._base_method = 'notifications.'

    def get(self, count: str = None, start_from: str = None, filters: str = None, start_time: str = None,
            end_time: str = None) -> dict:
        """
        Возвращает список оповещений об ответах других пользователей на записи текущего пользователя.

        :param count: указывает, какое максимальное число оповещений следует возвращать.
        :param start_from: строковый идентификатор оповещения, полученного последним в предыдущем вызове (см.
            описание поля next_from в результате).
        :param filters: перечисленные через запятую типы оповещений, которые необходимо получить. Возможные
            значения:   wall — записи на стене пользователя;  mentions — упоминания в записях на стене, в
            комментариях или в обсуждениях;  comments — комментарии к записям на стене, фотографиям и видеозаписям;
            likes — отметки «Мне нравится»;  reposts — скопированные у текущего пользователя записи на стене,
            фотографии и видеозаписи;  followers — новые подписчики;  friends — принятые заявки в друзья.  Если
            параметр не задан, то будут получены все возможные типы оповещений.
        :param start_time: время в формате Unixtime, начиная с которого следует получить оповещения для текущего
            пользователя. Если параметр не задан, то он считается равным значению времени, которое было сутки назад.
        :param end_time: время в формате Unixtime, до которого следует получить оповещения для текущего
            пользователя. Если параметр не задан, то он считается равным текущему времени.

        :return: После успешного выполнения возвращает объект, содержащий поля:  items  arrayмассив оповещений
            для текущего пользователя. profiles  arrayинформация о пользователях, которые находятся в списке
            оповещений. groups  arrayинформация о сообществах, которые находятся в списке оповещений. last_viewed
            integerвремя последнего просмотра пользователем раздела оповещений в формате Unixtime.   Описание поля
            items Поле items содержит массив объектов, каждый из которых соответствует одному оповещению. Каждый из
            объектов содержит поля: type stringтип оповещения. Подробнее см. ниже. date  integerвремя появления
            ответа в формате Unixtime. parent  object (отсутствует, если type= follow, mention или wall)информация о
            материале, к которому появился ответ (запись на стене, комментарий, фотографию, видеозапись или
            обсуждение). Подробнее см. в описании поля type ниже. feedback  [object,array]объект (или массив
            объектов, если type равно follow, like_* или copy_*), описывающий поступивший ответ. Оповещения о новых
            подписчиках, пометках «Мне нравится» и скопированных записях могут быть сгруппированы в виде массива.
            reply  objectобъект, описывающий комментарий текущего пользователя, отправленный в ответ на данное
            оповещение. Отсутствует, если пользователь ещё не давал ответа.   Описание поля type Поле type описывает
            тип оповещения. От данного типа зависит наличие и содержание полей parent и feedback. В данный момент
            поддерживаются следующие типы оповещений:  Значение type Тип поля parentТип поля feedbackОписание follow-
            user[]У пользователя появился один или несколько новых подписчиков. friend_accepted-user[]Заявка в
            друзья, отправленная пользователем, была принята. mention-postБыла создана запись на чужой стене,
            содержащая упоминание пользователя. mention_commentspostcommentБыл оставлен комментарий, содержащий
            упоминание пользователя. wall-postБыла добавлена запись на стене пользователя. wall_publish-postБыла
            опубликована новость, предложенная пользователем в публичной странице. comment_postpostcommentБыл
            добавлен новый комментарий к записи, созданной пользователем. comment_photophotocommentБыл добавлен новый
            комментарий к фотографии пользователя. comment_videovideocommentБыл добавлен новый комментарий к
            видеозаписи пользователя. reply_commentcommentcommentБыл добавлен новый ответ на комментарий
            пользователя. reply_comment_photocommentcommentБыл добавлен новый ответ на комментарий пользователя к
            фотографии. reply_comment_videocommentcommentБыл добавлен новый ответ на комментарий пользователя к
            видеозаписи. reply_comment_marketcommentcommentБыл добавлен новый ответ на комментарий пользователя к
            товару. reply_topictopiccommentБыл добавлен новый ответ пользователю в обсуждении. like_postpostuser[]У
            записи пользователя появилась одна или несколько новых отметок «Мне нравится». like_commentcommentuser[]У
            комментария пользователя появилась одна или несколько новых отметок «Мне нравится».
            like_photophotouser[]У фотографии пользователя появилась одна или несколько новых отметок «Мне нравится».
            like_videovideouser[]У видеозаписи пользователя появилась одна или несколько новых отметок «Мне
            нравится». like_comment_photocommentuser[]У комментария пользователя к фотографии появилась одна или
            несколько новых отметок «Мне нравится». like_comment_videocommentuser[]У комментария пользователя к
            видеозаписи появилась одна или несколько новых отметок «Мне нравится». like_comment_topiccommentuser[]У
            комментария пользователя в обсуждении появилась одна или несколько новых отметок «Мне нравится».
            copy_postpostcopy[]Один или несколько пользователей скопировали запись пользователя
            copy_photophotocopy[]Один или несколько пользователей скопировали фотографию пользователя.
            copy_videovideocopy[]Один или несколько пользователей скопировали видеозапись пользователя.
            mention_comment_photophotocommentПод фотографией был оставлен комментарий, содержащий упоминание
            пользователя. mention_comment_videovideocommentПод видео был оставлен комментарий, содержащий упоминание
            пользователя.   Описание поля parent (post) Содержит информацию о записи на стене:   id — идентификатор
            записи;  to_id — идентификатор владельца записи;  from_id — идентификатор пользователя, создавшего
            запись;  date — время публикации записи в формате unixtime;  text — текст записи;  attachments — содержит
            массив объектов, которые присоединены к текущей записи (фотографии, ссылки и т.п.). Более подробная
            информация представлена на странице Описание поля attachments.  geo — находится в записях со стен, в
            которых имеется информация о местоположении, содержит поля:   place_id — идентификатор места;  title —
            название места;  type — тип места;  country_id — идентификатор страны;  city_id — идентификатор города;
            address — строка с указанием адреса места в городе;  showmap — данный параметр указывается, если
            местоположение является прикреплённой картой.   copy_owner_id — если запись является копией записи с
            чужой стены, то в поле содержится идентификатор владельца стены у которого была скопирована запись;
            copy_post_id — если запись является копией записи с чужой стены, то в поле содержится идентификатор
            скопированной записи на стене ее владельца    Описание поля parent (comment) Содержит информацию о
            комментарии:   id — идентификатор комментария;  owner_id — идентификатор автора комментария;  date —
            время публикации комментария в формате unixtime;  text — текст комментария;  post — запись, к которой
            оставлен комментарий (для типов reply_comment и like_comment);  photo — фотография, к которой оставлен
            комментарий (для типов reply_comment_photo и like_comment_photo);  video — видеозапись, к которой
            оставлен комментарий (для типов reply_comment_video и like_comment_video);  topic — обсуждение, в котором
            оставлен комментарий (для типа like_comment_topic).    Описание поля parent (photo) Содержит информацию о
            фотографии:   id — идентификатор фотографии;  owner_id — идентификатор владельца фотографии;  aid —
            идентификатор альбома фотографии;  src — ссылка на изображение в разрешении 130 пикселей по большей
            стороне;  src_big — ccылка на изображение в разрешении 604 пикселя по большей стороне;  src_small —
            ссылка на изображение в разрешении 75 пикселей по большей стороне;  text — текст описания фотографии;
            created — дата загрузки фотографии в формате unixtime.    Описание поля parent (video) Содержит
            информацию о видеозаписи:   id — идентификатор видеозаписи;  owner_id — идентификатор владельца
            видеозаписи;  title — название видеозаписи;  description — описание видеозаписи;  duration —
            продолжительность видеозаписи в секундах;  link — ссылка на видео;  image — ссылка на изображение в
            разрешении 320 пикселей в ширину;  image_medium — ссылка на изображение в разрешении 160 пикселей в
            ширину;  date — дата добавления видеозаписи в формате unixtime;  views — количество просмотров;  player —
            ссылка на встраиваемый i_frame-видеоплеер.    Описание поля parent (topic) Содержит информацию о теме в
            обсуждениях сообщества:   id — идентификатор темы;  owner_id — идентификатор сообщества, содержащего тему
            в обсуждениях (со знаком "минус");  title — заголовок темы;  created — дата создания темы в формате
            unixtime;  created_by — идентификатор пользователя, создавшего тему;  updated — дата последнего сообщения
            в формате unixtime;  updated_by — идентификатор пользователя, оставившего последнее сообщение;  is_closed
            — 1, если тема является закрытой (в ней нельзя оставлять сообщения);  is_fixed — 1, если тема является
            прилепленной (находится в начале списка тем);  comments — число сообщений в теме.    Описание поля
            feedback Cодержит информацию об оповещении:   id (отсутствует, если type равно follow или like_*) —
            идентификатор записи-ответа;  to_id — идентификатор владельца стены, на которой размещена запись;
            from_id — идентификатор автора ответа;  text (отсутствует, если type равно follow, like_* или copy_*) —
            текст ответа;  likes — находится в записях со стен и содержит информацию о числе людей, которым
            понравилась данная запись, содержит поля:   count — число пользователей, которым понравилась запись,
            user_likes — наличие отметки «Мне нравится» от текущего пользователя  (1 — есть, 0 — нет),  can_like —
            информация о том, может ли текущий пользователь поставить отметку «Мне нравится»  (1 — может, 0 — не
            может),  can_publish — информация о том, может ли текущий пользователь сделать репост записи  (1 — может,
            0 — не может);    В случае, если ответ является записью на стене (тип post в таблице выше), в объекте
            feedback также содержатся следующие поля:   attachments — содержит массив объектов, которые присоединены
            к текущей записи (фотографии, ссылки и т.п.). Более подробная информация представлена на странице
            Описание поля attachments.  geo — находится в записях со стен, в которых имеется информация о
            местоположении, содержит поля:   place_id — идентификатор места;  title — название места;  type — тип
            места;  country_id — идентификатор страны;  city_id — идентификатор города;  address — строка с указанием
            адреса места в городе;  showmap — данный параметр указывается, если местоположение является прикреплённой
            картой.     Описание поля reply Cодержит информацию об ответе пользователя на оповещение:   id —
            идентификатор комментария;  date — время публикации комментария в формате unixtime;  text — текст
            комментария.    Описание поля profiles Поле profiles содержит массив объектов user с информацией о данных
            пользователей, которые присутствуют в новостях. Каждый из объектов содержит следующие поля:   uid —
            идентификатор пользователя;  first_name — имя пользователя;  last_name — фамилия пользователя;  photo —
            адрес фотографии пользователя размером 50x50px;  photo_medium_rec — адрес фотографии пользователя
            размером 100x100px;  screen_name — короткий адрес страницы пользователя (например, andrew или id6492)
        """

        params = locals()
        method_name = self._base_method + 'get'
        return self._call(method_name, params)

    def markAsViewed(self) -> dict:
        """
        Сбрасывает счетчик непросмотренных оповещений об ответах других пользователей на записи текущего пользователя.

        :return: Если у пользователя присутствовали непросмотренные ответы, возвращает 1 в случае успешного
            завершения. В противном случае возвращает 0
        """

        params = locals()
        method_name = self._base_method + 'markAsViewed'
        return self._call(method_name, params)

    def sendMessage(self, user_ids: str = None, message: str = None, fragment: str = None,
                    group_id: str = None) -> dict:
        """
        Отправляет уведомление пользователю приложения VK Apps.

        :param user_ids: список идентификаторов пользователей, которым нужно отправить уведомление (максимум 100
            идентификаторов).
        :param message: текст уведомления.
        :param fragment: содержимое хэша (часть URL в ссылке на приложение вида
            https://vk.com/app123456#fragment).
        :param group_id:

        :return: После успешного выполнения возвращает массив объектов, каждый из которых содержит поля:
            user_id (integer) —  идентификатор пользователя;  status (boolean) — true, если уведомление отправлено
            успешно. Иначе false.  error (object) — в случае, если статус отправки имеет значение false,
            дополнительно вернётся объект ошибки, содержащий код ошибки в поле code (integer) и описание description
            (string).   Возможные значения code:   1 — уведомления приложения отключены;  2 — отправлено слишком
            много уведомлений за последний час;  3 — отправлено слишком много уведомлений за последние сутки;  4 —
            приложение не установлено
        """

        params = locals()
        method_name = self._base_method + 'sendMessage'
        return self._call(method_name, params)






from ApiMethod import ApiMethod


class Docs(ApiMethod):
    def __init__(self, access_token, v, session, calls_per_second):
        super(Docs, self).__init__(access_token, v, session, calls_per_second)
        self._base_method = 'docs.'


    def add(self, owner_id: str = None, doc_id: str = None, access_key: str = None) -> dict:
        """
        Копирует документ в документы текущего пользователя.

        :param owner_id: идентификатор пользователя или сообщества, которому принадлежит документ.  Обратите
            внимание, идентификатор сообщества в параметре owner_id необходимо указывать со знаком "-" — например,
            owner_id=-1 соответствует идентификатору сообщества ВКонтакте API (club1)
        :param doc_id: идентификатор документа.
        :param access_key: ключ доступа документа. Этот параметр следует передать, если вместе с остальными
            данными о документе было возвращено поле access_key.

        :return: После успешного выполнения возвращает идентификатор созданного документа
        """

        params = locals()
        method_name = self._base_method + 'add'
        return self._call(method_name, params)

    def delete(self, owner_id: str = None, doc_id: str = None) -> dict:
        """
        Удаляет документ пользователя или группы.

        :param owner_id: идентификатор пользователя или сообщества, которому принадлежит документ.  Обратите
            внимание, идентификатор сообщества в параметре owner_id необходимо указывать со знаком "-" — например,
            owner_id=-1 соответствует идентификатору сообщества ВКонтакте API (club1)
        :param doc_id: идентификатор документа.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'delete'
        return self._call(method_name, params)

    def edit(self, owner_id: str = None, doc_id: str = None, title: str = None, tags: str = None) -> dict:
        """
        Редактирует документ пользователя или группы.

        :param owner_id: идентификатор пользователя или сообщества, которому принадлежит документ.  Обратите
            внимание, идентификатор сообщества в параметре owner_id необходимо указывать со знаком "-" — например,
            owner_id=-1 соответствует идентификатору сообщества ВКонтакте API (club1)
        :param doc_id: идентификатор документа.
        :param title: название документа.
        :param tags: метки для поиска.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'edit'
        return self._call(method_name, params)

    def get(self, count: str = None, offset: str = None, type: str = None, owner_id: str = None,
            return_tags: str = None) -> dict:
        """
        Возвращает расширенную информацию о документах пользователя или сообщества.

        :param count: количество документов, информацию о которых нужно вернуть.  По умолчанию: все документы.
            Максимальное количество документов, которое можно получить: 2000.
        :param offset: смещение, необходимое для выборки определенного подмножества документов. Максимальное
            значение: 1999.
        :param type: фильтр по типу документа.  Возможные варианты:   1 — текстовые документы;  2 — архивы;  3 —
            gif;  4 — изображения;  5 — аудио;  6 — видео;  7 — электронные книги;  8 — неизвестно.
        :param owner_id: идентификатор пользователя или сообщества, которому принадлежат документы.  Обратите
            внимание, идентификатор сообщества в параметре owner_id необходимо указывать со знаком "-" — например,
            owner_id=-1 соответствует идентификатору сообщества ВКонтакте API (club1)
        :param return_tags:

        :return: После успешного выполнения возвращает объект, содержащий число результатов в поле count и массив
            объектов документов в поле items
        """

        params = locals()
        method_name = self._base_method + 'get'
        return self._call(method_name, params)

    def getById(self, docs: str = None, return_tags: str = None) -> dict:
        """
        Возвращает информацию о документах по их идентификаторам.

        :param docs: идентификаторы документов, информацию о которых нужно вернуть. Пример значения docs:
            66748_91488,66748_91455.  Метод поддерживает передачу access_key.
        :param return_tags:

        :return: После успешного выполнения возвращает объект, содержащий число результатов в поле count и массив
            объектов документов в поле items
        """

        params = locals()
        method_name = self._base_method + 'getById'
        return self._call(method_name, params)

    def getMessagesUploadServer(self, type: str = None, peer_id: str = None) -> dict:
        """
        Получает адрес сервера для загрузки документа в личное сообщение.

        :param type: тип документа. Возможные значения:   doc — обычный документ;  audio_message — голосовое
            сообщение;  graffiti — граффити.
        :param peer_id: идентификатор назначения.  Для пользователя:  id пользователя.   Для групповой беседы:
            2000000000 + id беседы.   Для сообщества:  -id сообщества.

        :return: Возвращает объект с единственным полем upload_url (string), содержащим адрес сервера для
            загрузки документа
        """

        params = locals()
        method_name = self._base_method + 'getMessagesUploadServer'
        return self._call(method_name, params)

    def getTypes(self, owner_id: str = None) -> dict:
        """
        Возвращает доступные для пользователя типы документов.

        :param owner_id: идентификатор пользователя или сообщества, которому принадлежат документы.

        :return: После успешного выполнения возвращает список объектов type с полями, описанными ниже:  id
            integer идентификатор типа. name  string название типа. count   integer число документов
        """

        params = locals()
        method_name = self._base_method + 'getTypes'
        return self._call(method_name, params)

    def getUploadServer(self, group_id: str = None) -> dict:
        """
        Возвращает адрес сервера для загрузки документов.

        :param group_id: идентификатор сообщества (если необходимо загрузить документ в список документов
            сообщества). Если документ нужно загрузить в список пользователя, метод вызывается без дополнительных
            параметров.

        :return: Возвращает объект с полем upload_url, содержащим адрес для загрузки файла. После успешной
            загрузки документа необходимо воспользоваться методом docs.save
        """

        params = locals()
        method_name = self._base_method + 'getUploadServer'
        return self._call(method_name, params)

    def getWallUploadServer(self, group_id: str = None) -> dict:
        """
        Возвращает адрес сервера для загрузки документов в папку Отправленные, для последующей отправки документа на
        стену или личным сообщением.

        :param group_id: идентификатор сообщества, в которое нужно загрузить документ.

        :return: Возвращает объект с полем upload_url. После успешной загрузки документа необходимо
            воспользоваться методом docs.save
        """

        params = locals()
        method_name = self._base_method + 'getWallUploadServer'
        return self._call(method_name, params)

    def save(self, file: str = None, title: str = None, tags: str = None, return_tags: str = None) -> dict:
        """
        Сохраняет документ после его успешной загрузки на сервер.

        :param file: параметр, возвращаемый в результате загрузки файла на сервер.
        :param title: название документа.
        :param tags: метки для поиска.
        :param return_tags:

        :return: После успешного выполнения возвращает массив объектов, описывающих загруженные документы. Каждый
            объект массива содержит поле type (string) с возможными значениями graffiti, audio_message, doc, и
            одноименный объект, описывающий загруженный документ.  Для type = graffiti объект graffiti, описывающий
            граффити.  Для type = audio_message объект audio_message, описывающий голосовое сообщение.  Для type =
            doc объект doc, описывающий другие типы документов
        """

        params = locals()
        method_name = self._base_method + 'save'
        return self._call(method_name, params)

    def search(self, q: str = None, search_own: str = None, count: str = None, offset: str = None,
               return_tags: str = None) -> dict:
        """
        Возвращает результаты поиска по документам.

        :param q: строка поискового запроса. Например, зеленые тапочки.
        :param search_own: 1 — искать среди собственных документов пользователя.
        :param count: количество документов, информацию о которых нужно вернуть. Обратите внимание — даже при
            использовании параметра offset для получения информации доступны только первые 1000 результатов.
        :param offset: смещение, необходимое для выборки определенного подмножества документов.
        :param return_tags:

        :return: После успешного выполнения возвращает список объектов документов.  Если установлен флаг
            search_own, в поле local дополнительно вернется список документов из локального поиска
        """

        params = locals()
        method_name = self._base_method + 'search'
        return self._call(method_name, params)




from ApiMethod import ApiMethod


class Newsfeed(ApiMethod):
    def __init__(self, access_token, v, session, calls_per_second):
        super(Newsfeed, self).__init__(access_token, v, session, calls_per_second)
        self._base_method = 'newsfeed.'

    def addBan(self, user_ids: str = None, group_ids: str = None) -> dict:
        """
        Запрещает показывать новости от заданных пользователей и групп в ленте новостей текущего пользователя.

        :param user_ids: перечисленные через запятую идентификаторы друзей пользователя, новости от которых
            необходимо скрыть из ленты новостей текущего пользователя.
        :param group_ids: перечисленные через запятую идентификаторы групп пользователя, новости от которых
            необходимо скрыть из ленты новостей текущего пользователя.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'addBan'
        return self._call(method_name, params)

    def deleteBan(self, user_ids: str = None, group_ids: str = None) -> dict:
        """
        Разрешает показывать новости от заданных пользователей и групп в ленте новостей текущего пользователя.

        :param user_ids: идентификаторы пользователей, новости от которых необходимо вернуть в ленту.
        :param group_ids: идентификаторы сообществ, новости от которых необходимо вернуть в ленту.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'deleteBan'
        return self._call(method_name, params)

    def deleteList(self, list_id: str = None) -> dict:
        """
        Метод позволяет удалить пользовательский список новостей

        :param list_id: числовой идентификатор списка

        :return
        """

        params = locals()
        method_name = self._base_method + 'deleteList'
        return self._call(method_name, params)

    def get(self, filters: str = None, return_banned: str = None, start_time: str = None, end_time: str = None,
            max_photos: str = None, source_ids: str = None, start_from: str = None, count: str = None,
            fields: str = None, section: str = None) -> dict:
        """
        Возвращает данные, необходимые для показа списка новостей для текущего пользователя.

        :param filters: перечисленные через запятую названия списков новостей, которые необходимо получить. В
            данный момент поддерживаются следующие списки новостей:   post — новые записи со стен;  photo — новые
            фотографии;  photo_tag — новые отметки на фотографиях;  wall_photo — новые фотографии на стенах;  friend
            — новые друзья;  note — новые заметки;  audio — записи сообществ и друзей, содержащие аудиозаписи, а
            также новые аудиозаписи, добавленные ими;  video — новые видеозаписи.   Если параметр не задан, то будут
            получены все возможные списки новостей.
        :param return_banned: 1 - включить в выдачу также скрытых из новостей пользователей. 0 - не возвращать
            скрытых пользователей.
        :param start_time: время в формате unixtime, начиная с которого следует получить новости для текущего
            пользователя.
        :param end_time: время в формате unixtime, до которого следует получить новости для текущего
            пользователя. Если параметр не задан, то он считается равным текущему времени.
        :param max_photos: Максимальное количество фотографий, информацию о которых необходимо вернуть. По
            умолчанию: 5, максимальное значение: 100.
        :param source_ids: перечисленные через запятую иcточники новостей, новости от которых необходимо
            получить.  Идентификаторы пользователей можно указывать в форматах <uid> или u<uid> где <uid> —
            идентификатор друга пользователя.  Идентификаторы сообществ можно указывать в форматах -<gid> или g<gid>
            где <gid> — идентификатор сообщества.  Помимо этого параметр может принимать строковые значения:
            friends - список друзей пользователя  groups - список групп, на которые подписан текущий пользователь
            pages - список публичных страниц, на который подписан тeкущий пользователь  following - список
            пользователей, на которых подписан текущий пользователь  list{идентификатор списка новостей} - список
            новостей. Вы можете найти все списки новостей пользователя используя метод newsfeed.getLists   Если
            параметр не задан, то считается, что он включает список всех друзей и групп пользователя, за исключением
            скрытых источников, которые можно получить методом newsfeed.getBanned.  Максимальное число символов —
            5000.
        :param start_from: Идентификатор, необходимый для получения следующей страницы результатов. Значение,
            необходимое для передачи в этом параметре, возвращается в поле ответа next_from.
        :param count: указывает, какое максимальное число новостей следует возвращать, но не более 100. По
            умолчанию 50.
        :param fields: список дополнительных полей для профилей и групп, которые необходимо вернуть. См. описание
            полей объекта user и описание полей объекта group.
        :param section:

        :return: После успешного выполнения возвращает объект, содержащий следующие поля:   items — массив
            новостей для текущего пользователя;  profiles — информация о пользователях, которые находятся в списке
            новостей;  groups — информация о группах, которые находятся в списке новостей;  new_offset — содержит
            offset, который необходимо передать, для того, чтобы получить следующую часть новостей;  next_from —
            содержит start_from, который необходимо передать, для того, чтобы получить следующую часть новостей.
            Позволяет избавиться от дубликатов, которые могут возникнуть при появлении новых новостей между вызовами
            этого метода.    Описание поля items Поле items содержит массив объектов, каждый из которых соответствует
            одной новости в ленте. Каждый из объектов содержит поля:   type — тип списка новости, соответствующий
            одному из значений параметра filters;  source_id — идентификатор источника новости (положительный —
            новость пользователя, отрицательный — новость группы);  date — время публикации новости в формате
            unixtime;  post_id — находится в записях со стен и содержит идентификатор записи на стене владельца;
            post_type — находится в записях со стен, содержит тип новости (post или copy);  final_post — передается в
            случае, если этот пост сделан при удалении;  copy_owner_id — находится в записях со стен, если сообщение
            является копией сообщения с чужой стены, и содержит идентификатор владельца стены, у которого было
            скопировано сообщение;  copy_post_id — находится в записях со стен, если сообщение является копией
            сообщения с чужой стены, и содержит идентификатор скопированного сообщения на стене его владельца;
            copy_history — массив, содержащий историю репостов для записи. Возвращается только в том случае, если
            запись является репостом. Каждый из объектов массива, в свою очередь, является объектом-записью
            стандартного формата.  copy_post_date — находится в записях со стен, если сообщение является копией
            сообщения с чужой стены, и содержит дату скопированного сообщения;  text — находится в записях со стен и
            содержит текст записи;  can_edit — содержит 1, если текущий пользователь может редактировать запись;
            can_delete — возвращается, если пользователь может удалить новость, всегда содержит 1;  comments —
            находится в записях со стен и содержит информацию о комментариях к записи, содержит поля:   count —
            количество комментариев,  can_post — информация о том, может ли текущий пользователь комментировать
            запись  (1 — может, 0 — не может);   likes — находится в записях со стен и содержит информацию о числе
            людей, которым понравилась данная запись, содержит поля:   count — число пользователей, которым
            понравилась запись,  user_likes — наличие отметки «Мне нравится» от текущего пользователя  (1 — есть, 0 —
            нет),  can_like — информация о том, может ли текущий пользователь поставить отметку «Мне нравится»  (1 —
            может, 0 — не может),  can_publish — информация о том, может ли текущий пользователь сделать репост
            записи  (1 — может, 0 — не может);   reposts — находится в записях со стен и содержит информацию о числе
            людей, которые скопировали данную запись на свою страницу, содержит поля:   count — число пользователей,
            сделавших репост;  user_reposted — наличие репоста от текущего пользователя (0 — нет, 1 — есть);
            attachments — находится в записях со стен и содержит массив объектов, которые прикреплены к текущей
            новости (фотография, ссылка и т.п.). Более подробная информация представлена на странице Описание поля
            attachments.  geo — находится в записях со стен, в которых имеется информация о местоположении, содержит
            поля:   place_id — идентификатор места;  title — название места;  type — тип места;  country_id —
            идентификатор страны;  city_id — идентификатор города;  address — строка с указанием адреса места в
            городе;  showmap — данный параметр указывается, если местоположение является прикреплённой картой.
            photos, photo_tags, notes, friends — находятся в объектах соответствующих типов (кроме записей со стен) и
            содержат информацию о количестве объектов и до 5 последних объектов, связанных с данной новостью.  Каждый
            из элементов массива в полях photos и photo_tags содержит поля:    id — идентификатор фотографии
            owner_id — идентификатор владельца фотографии  album_id — идентификатор альбома  src — адрес изображения
            для предпросмотра  src_big — адрес полноразмерного изображения  Каждый из элементов массива в поле notes
            содержит поля:   id — идентификатор заметки  owner_id — идентификатор владельца заметки  title —
            заголовок заметки  comments — количество комментариев к заметке  Каждый из элементов массива в поле
            friends содержит поля:   uid— идентификатор пользователя     Описание поля profiles Поле profiles
            содержит массив объектов пользователей с дополнительными полями:   photo — адрес фотографии пользователя
            размером 50x50px;  photo_medium_rec — адрес фотографии пользователя размером 100x100px;  screen_name —
            короткий адрес страницы пользователя (например, andrew или id6492).    Описание поля groups Поле groups
            содержит массив объектов сообществ, которые присутствуют в новостях.   Примечание Вы можете получить
            полный список фотографий, полученных с типом photo или photo_tag методом photos.get, указав параметры
            feed (дата события в поле date) и feed_type (тип события, photo или photo_tag) и uid — идентификатор
            пользователя, с которым произошло событие (поле source_id)
        """

        params = locals()
        method_name = self._base_method + 'get'
        return self._call(method_name, params)

    def getBanned(self, extended: str = None, fields: str = None, name_case: str = None) -> dict:
        """
        Возвращает список пользователей и групп, которые текущий пользователь скрыл из ленты новостей.

        :param extended: если этот параметр равен 1, возвращается дополнительная информация о пользователях и
            группах
        :param fields: список дополнительных полей профилей, которые необходимо вернуть. См. подробное описание.
            Доступные значения: sex, bdate, city, country, photo_50, photo_100, photo_200_orig, photo_200,
            photo_400_orig, photo_max, photo_max_orig, online, online_mobile, domain, has_mobile, contacts,
            connections, site, education, universities, schools, can_post, can_see_all_posts, can_see_audio,
            can_write_private_message, status, last_seen, common_count, relation, relatives, counters, screen_name,
            maiden_name, timezone, occupation,activities, interests, music, movies, tv, books, games, about, quotes
        :param name_case: падеж для склонения имени и фамилии пользователя. Возможные значения: именительный –
            nom, родительный – gen, дательный – dat, винительный – acc, творительный – ins, предложный – abl. По
            умолчанию nom.

        :return: В случае успеха возвращает объект, в котором содержатся поля groups и members или profiles, в
            зависимости от параметра extended.  Если extended=0:   В поле groups содержится массив идентификаторов
            сообществ, которые пользователь скрыл из ленты новостей. В поле members содержится массив идентификаторов
            пользователей, которых пользователь скрыл из ленты новостей.   Если extended=1:   В поле groups
            содержится массив объектов с информацией о сообществах. В поле profiles содержится массив объектов с
            информацией о пользователях
        """

        params = locals()
        method_name = self._base_method + 'getBanned'
        return self._call(method_name, params)

    def getComments(self, count: str = None, filters: str = None, reposts: str = None, start_time: str = None,
                    end_time: str = None, last_comments_count: str = None, start_from: str = None,
                    fields: str = None) -> dict:
        """
        Возвращает данные, необходимые для показа раздела комментариев в новостях пользователя.

        :param count: указывает, какое максимальное число новостей следует возвращать, но не более 100. По
            умолчанию 30. Для автоподгрузки Вы можете использовать возвращаемый данным методом параметр new_offset.
        :param filters: перечисленные через запятую типы объектов, изменения комментариев к которым нужно
            вернуть. В данный момент поддерживаются следующие списки новостей:    post — новые комментарии к записям
            со стен;  photo — новые комментарии к фотографиям;  video — новые комментарии к видеозаписям;  topic —
            новые сообщения в обсуждениях;  market — новые комментарии к товарам;  note — новые комментарии к
            заметкам. Если параметр не задан, то будут получены все возможные списки новостей.
        :param reposts: Идентификатор объекта, комментарии к репостам которого необходимо вернуть, например
            wall1_45486. Если указан данный параметр, параметр filters указывать необязательно.
        :param start_time: время в формате unixtime, начиная с которого следует получить новости для текущего
            пользователя. Если параметр не задан, то он считается равным значению времени, которое было сутки назад.
        :param end_time: время в формате unixtime, до которого следует получить новости для текущего
            пользователя. Если параметр не задан, то он считается равным текущему времени.
        :param last_comments_count: количество комментариев к записям, которые нужно получить.
        :param start_from: Идентификатор, необходимый для получения следующей страницы результатов. Значение,
            необходимое для передачи в этом параметре, возвращается в поле ответа next_from.
        :param fields: список дополнительных полей профилей, которые необходимо вернуть. См. подробное описание.
            Доступные значения: sex, bdate, city, country, photo_50, photo_100, photo_200_orig, photo_200,
            photo_400_orig, photo_max, photo_max_orig, online, online_mobile, domain, has_mobile, contacts,
            connections, site, education, universities, schools, can_post, can_see_all_posts, can_see_audio,
            can_write_private_message, status, last_seen, common_count, relation, relatives, counters, screen_name,
            maiden_name, timezone, occupation,activities, interests, music, movies, tv, books, games, about, quotes

        :return: В случае успеха возвращает объект, содержащий поля:   items — содержит массив новостей для
            текущего пользователя  profiles — содержит информацию о пользователях, которые находятся в списке
            новостей  groups — содержит информацию о группах, которые находятся в списке новостей  next_from —
            содержит текстовое поле, которое необходимо передать при подгрузке следующего блока обсуждений
            Описание поля items Поле items содержит массив объектов, каждый из которых соответствует одной новости в
            ленте. Каждый из объектов содержит поля:   type — тип списка новости, соответствующий одному из значений
            параметра filters  source_id — идентификатор источника новости (положительный — новость пользователя,
            отрицательный — новость сообщества)  date — время публикации новости в формате unixtime  post_id —
            находится в записях со стен и содержит идентификатор записи на стене владельца  copy_owner_id — находится
            в записях со стен, если сообщение является копией сообщения с чужой стены, и содержит идентификатор
            владельца стены, у которого было скопировано сообщение  copy_post_id — находится в записях со стен, если
            сообщение является копией сообщения с чужой стены, и содержит идентификатор скопированного сообщения на
            стене его владельца  text — находится в записях со стен и содержит текст записи  comments — находится в
            записях со стен и содержит информацию о комментариях к записи, содержит поля:   count — количество
            комментариев,  can_post — информация о том, может ли текущий пользователь комментировать запись (1 —
            может, 0 — не может);   likes — находится в записях со стен и содержит информацию о числе людей, которым
            понравилась данная запись, содержит поля:   count — число пользователей, которым понравилась запись,
            user_likes — наличие отметки «Мне нравится» от текущего пользователя (1 — есть, 0 — нет),  can_like —
            информация о том, может ли текущий пользователь поставить отметку «Мне нравится» (1 — может, 0 — не
            может),  can_publish — информация о том, может ли текущий пользователь сделать репост записи (1 — может,
            0 — не может);   attachment — находится в записях со стен и содержит объект, который присоединен к
            текущей новости (фотография, ссылка и т.п.). Более подробная информация представлена на странице Описание
            поля attachment.  geo — находится в записях со стен, в которых имеется информация о местоположении,
            содержит поля:   place_id — идентификатор места;  title — название места;  type — тип места;  country_id
            — идентификатор страны;  city_id — идентификатор города;  address — строка с указанием адреса места в
            городе;  showmap — данный параметр указывается, если местоположение является прикреплённой картой.
            photos, photo_tags, notes, friends — находятся в объектах соответствующих типов (кроме записей со стен) и
            содержат информацию о количестве объектов и до 5 последних объектов, связанных с данной новостью.  Каждый
            из элементов массива в полях photos и photo_tags содержит поля:   id — идентификатор фотографии;
            owner_id — идентификатор владельца фотографии;  album_id — идентификатор альбома;  photo_* — адреса
            различных размеров изображений для фотографии (75, 130, 604, 807, 1280, 2560 px)  Каждый из элементов
            массива в поле notes содержит поля:   id — идентификатор заметки;  owner_id — идентификатор владельца
            заметки;  title — заголовок заметки;  ncom — количество комментариев к заметке.  Каждый из элементов
            массива в поле friends содержит единственное поле   uid — идентификатор пользователя.     Описание поля
            profiles Поле profiles содержит массив объектов с информацией о данных пользователей, которые
            присутствуют в новостях.  Каждый из объектов содержит поля:   id — идентификатор пользователя;
            first_name — имя пользователя;  last_name — фамилия пользователя;  photo — адрес фотографии пользователя
            размером 50x50 px.    Описание поля groups Поле groups содержит массив объектов с информацией о
            сообществах, которые присутствуют в новостях. Каждый из объектов содержит поля:   id — идентификатор
            сообщества;  name — название сообщества;  photo — адрес логотипа группы шириной 50px
        """

        params = locals()
        method_name = self._base_method + 'getComments'
        return self._call(method_name, params)

    def getLists(self, list_ids: str = None, extended: str = None) -> dict:
        """
        Возвращает пользовательские списки новостей.

        :param list_ids: идентификаторы списков.
        :param extended: 1 — вернуть дополнительную информацию о списке (значения source_ids и no_reposts).

        :return: Метод возвращает список объектов с полями:   id – идентификатор списка;  title – название
            списка, заданное пользователем.   Если был передан параметр extended=1, дополнительно возвращаются поля:
            no_reposts — отключены ли копии постов;  source_ids — идентификаторы пользователей и сообществ,
            включенных в список.   Новости по отдельному списку могут быть получены методом newsfeed.get с
            использованием параметра source_ids
        """

        params = locals()
        method_name = self._base_method + 'getLists'
        return self._call(method_name, params)

    def getMentions(self, owner_id: str = None, start_time: str = None, end_time: str = None, offset: str = None,
                    count: str = None) -> dict:
        """
        Возвращает список записей пользователей на своих стенах, в которых упоминается указанный пользователь.

        :param owner_id: идентификатор пользователя или сообщества.
        :param start_time: время в формате unixtime начиная с которого следует получать упоминания о
            пользователе.  Если параметр не задан, то будут возвращены все упоминания о пользователе, если не задан
            параметр end_time, в противном случае упоминания с учетом параметра end_time.
        :param end_time: время, в формате unixtime, до которого следует получать упоминания о пользователе.  Если
            параметр не задан, то будут возвращены все упоминания о пользователе, если не задан параметр start_time,
            в противном случае упоминания с учетом параметра start_time.
        :param offset: смещение, необходимое для выборки определенного подмножества новостей. По умолчанию 0.
        :param count: количество возвращаемых записей. Если параметр не задан, то считается, что он равен 20.
            Максимальное значение параметра 50.

        :return: В случае успеха возвращает количество записей и массив соответствующих им объектов, каждый из
            которых содержит следующие поля:   id — идентификатор записи на стене пользователя;  from_id —
            идентификатор пользователя, написавшего запись;  date — время публикаии записи в формате unixtime;  text
            — текст записи;  likes — содержит информацию о числе людей, которым понравилась данная запись, и
            понравилась ли она текущему пользователю;  comments — содержит информацию о количестве комментариев к
            записи и возможности текущего пользователя оставлять комментарии к ней;  attachment — содержит объект,
            который присоединен к текущей новости ( фотография, ссылка и т.п.). Более подробная информация
            представлена на странице Описание поля attachment;  geo — находится в записях со стен, в которых имеется
            информация о местоположении, содержит поля:   place_id — идентификатор места;  title — название места;
            type — тип места;  country_id — идентификатор страны;  city_id — идентификатор города;  address — строка
            с указанием адреса места в городе;  showmap — данный параметр указывается, если местоположение является
            прикреплённой картой.   copy_owner_id — если запись является копией записи с чужой стены, то в поле
            содержится идентификатор владельца стены у которого была скопирована запись;  copy_post_id — если запись
            является копией записи с чужой стены, то в поле содержится идентфикатор скопированной записи на стене ее
            владельца
        """

        params = locals()
        method_name = self._base_method + 'getMentions'
        return self._call(method_name, params)

    def getRecommended(self, start_time: str = None, end_time: str = None, max_photos: str = None,
                       start_from: str = None, count: str = None, fields: str = None) -> dict:
        """
        Получает список новостей, рекомендованных пользователю.

        :param start_time: время в формате unixtime, начиная с которого следует получить новости для текущего
            пользователя. Если параметр не задан, то он считается равным значению времени, которое было сутки назад.
        :param end_time: время в формате unixtime, до которого следует получить новости для текущего
            пользователя. Если параметр не задан, то он считается равным текущему времени.
        :param max_photos: Максимальное количество фотографий, информацию о которых необходимо вернуть. По
            умолчанию 5.
        :param start_from: Идентификатор, необходимый для получения следующей страницы результатов. Значение,
            необходимое для передачи в этом параметре, возвращается в поле ответа next_from.
        :param count: указывает, какое максимальное число новостей следует возвращать, но не более 100. По
            умолчанию 50.
        :param fields: список дополнительных полей профилей, которые необходимо вернуть. См. подробное описание.
            Доступные значения: sex, bdate, city, country, photo_50, photo_100, photo_200_orig, photo_200,
            photo_400_orig, photo_max, photo_max_orig, online, online_mobile, domain, has_mobile, contacts,
            connections, site, education, universities, schools, can_post, can_see_all_posts, can_see_audio,
            can_write_private_message, status, last_seen, common_count, relation, relatives, counters, screen_name,
            maiden_name, timezone, occupation,activities, interests, music, movies, tv, books, games, about, quotes

        :return: После успешного выполнения возвращает объект, содержащий следующие поля:   items — массив
            новостей для текущего пользователя;  profiles — информация о пользователях, которые находятся в списке
            новостей;  groups — информация о группах, которые находятся в списке новостей;  new_offset — содержит
            offset, который необходимо передать, для того, чтобы получить следующую часть новостей;  new_from —
            содержит from, который необходимо передать, для того, чтобы получить следующую часть новостей. Позволяет
            избавиться от дубликатов, которые могут возникнуть при появлении новых новостей между вызовами этого
            метода.    Описание поля items Поле items содержит массив объектов, каждый из которых соответствует одной
            новости в ленте. Каждый из объектов содержит поля:   type — тип списка новости, соответствующий одному из
            значений параметра filters;  source_id — идентификатор источника новости (положительный — новость
            пользователя, отрицательный — новость группы);  date — время публикации новости в формате unixtime;
            post_id — находится в записях со стен и содержит идентификатор записи на стене владельца;  copy_owner_id
            — находится в записях со стен, если сообщение является копией сообщения с чужой стены, и содержит
            идентификатор владельца стены, у которого было скопировано сообщение;  copy_post_id — находится в записях
            со стен, если сообщение является копией сообщения с чужой стены, и содержит идентификатор скопированного
            сообщения на стене его владельца;  copy_post_date — находится в записях со стен, если сообщение является
            копией сообщения с чужой стены, и содержит дату скопированного сообщения;  text — находится в записях со
            стен и содержит текст записи;  comments — находится в записях со стен и содержит информацию о
            комментариях к записи, содержит поля:   count — количество комментариев,  can_post — информация о том,
            может ли текущий пользователь комментировать запись  (1 — может, 0 — не может);   likes — находится в
            записях со стен и содержит информацию о числе людей, которым понравилась данная запись, содержит поля:
            count — число пользователей, которым понравилась запись,  user_likes — наличие отметки «Мне нравится» от
            текущего пользователя  (1 — есть, 0 — нет),  can_like — информация о том, может ли текущий пользователь
            поставить отметку «Мне нравится»  (1 — может, 0 — не может),  can_publish — информация о том, может ли
            текущий пользователь сделать репост записи  (1 — может, 0 — не может);   reposts — находится в записях со
            стен и содержит информацию о числе людей, которые скопировали данную запись на свою страницу, содержит
            поля:   count — число пользователей, сделавших репост;  user_reposted — наличие репоста от текущего
            пользователя (0 — нет, 1 — есть);   attachments — находится в записях со стен и содержит массив объектов,
            которые прикреплены к текущей новости (фотография, ссылка и т.п.). Более подробная информация
            представлена на странице Описание поля attachments.  geo — находится в записях со стен, в которых имеется
            информация о местоположении, содержит поля:   place_id — идентификатор места;  title — название места;
            type — тип места;  country_id — идентификатор страны;  city_id — идентификатор города;  address — строка
            с указанием адреса места в городе;  showmap — данный параметр указывается, если местоположение является
            прикреплённой картой.      photos, photo_tags, notes, friends — находятся в объектах соответствующих
            типов (кроме записей со стен) и содержат информацию о количестве объектов и до 5 последних объектов,
            связанных с данной новостью.   Каждый из элементов массива в полях photos и photo_tags содержит поля:
            id — идентификатор фотографии  owner_id — идентификатор владельца фотографии  album_id — идентификатор
            альбома  photo_75 - адрес изображения размером 75 пикселей  photo_130 - адрес изображения размером 130
            пикселей  photo_604 - адрес изображения размером 604 пикселей  photo_807 - адрес изображения размером 807
            пикселей  photo_1280 - адрес изображения размером 1280 пикселей    Каждый из элементов массива в поле
            notes содержит поля:     id — идентификатор заметки  owner_id — идентификатор владельца заметки  title —
            заголовок заметки  comments — количество комментариев к заметке    Каждый из элементов массива в поле
            friends содержит поля:     uid— идентификатор пользователя     Описание поля profiles Поле profiles
            содержит массив объектов user с информацией о данных пользователей, которые присутствуют в новостях.
            Каждый из объектов содержит следующие поля:   id — идентификатор пользователя;  first_name — имя
            пользователя;  last_name — фамилия пользователя;  photo — адрес фотографии пользователя размером 50x50px;
            photo_medium_rec — адрес фотографии пользователя размером 100x100px;  screen_name — короткий адрес
            страницы пользователя (например, andrew или id6492).    Описание поля groups Поле groups содержит массив
            объектов group с информацией о сообществах, которые присутствуют в новостях. Каждый из объектов содержит
            следующие поля:   id — идентификатор сообщества;  name — название сообщества;  is_closed — флаг,
            определяющий является ли группа закрытой;  photo — адрес логотипа группы шириной 50px;  photo_medium —
            адрес логотипа группы шириной 100px;  photo_big — адрес логотипа группы шириной 200px;  screen_name —
            короткий адрес страницы сообщества (например, apiclub или club1).    Примечание Вы можете получить полный
            список фотографий, полученных с типом photo или photo_tag методом photos.get, указав параметры feed (дата
            события в поле date) и feed_type (тип события, photo или photo_tag) и uid — идентификатор пользователя, с
            которым произошло событие (поле source_id)
        """

        params = locals()
        method_name = self._base_method + 'getRecommended'
        return self._call(method_name, params)

    def getSuggestedSources(self, offset: str = None, count: str = None, shuffle: str = None,
                            fields: str = None) -> dict:
        """
        Возвращает сообщества и пользователей, на которые текущему пользователю рекомендуется подписаться.

        :param offset: отступ, необходимый для выборки определенного подмножества сообществ или пользователей.
        :param count: количество сообществ или пользователей, которое необходимо вернуть.
        :param shuffle: перемешивать ли возвращаемый список.
        :param fields: список дополнительных полей, которые необходимо вернуть. См. возможные поля для
            пользователей и сообществ.

        :return: Список объектов пользователей и групп
        """

        params = locals()
        method_name = self._base_method + 'getSuggestedSources'
        return self._call(method_name, params)

    def ignoreItem(self, type: str = None, owner_id: str = None, item_id: str = None) -> dict:
        """
        Позволяет скрыть объект из ленты новостей.

        :param type: Тип объекта. Возможные значения:   wall — запись на стене;  tag — отметка на фотографии;
            profilephoto — фотография профиля;  video — видеозапись;  photo — фотография;  audio — аудиозапись.
        :param owner_id: Идентификатор владельца объекта (пользователь или сообщество). Обратите внимание,
            идентификатор сообщества в параметре owner_id необходимо указывать со знаком "-" — например, owner_id=-1
            соответствует идентификатору сообщества ВКонтакте API (club1)
        :param item_id: Идентификатор объекта.

        :return: В результате успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'ignoreItem'
        return self._call(method_name, params)

    def saveList(self, list_id: str = None, title: str = None, source_ids: str = None, no_reposts: str = None) -> dict:
        """
        Метод позволяет создавать или редактировать пользовательские списки для просмотра новостей.

        :param list_id: числовой идентификатор списка (если не передан, будет назначен автоматически).
        :param title: название списка.
        :param source_ids: идентификаторы пользователей и сообществ, которые должны быть включены в список.
            Идентификаторы сообществ нужно указывать со знаком «минус».
        :param no_reposts: нужно ли отображать копии постов в списке (1 — не нужно).

        :return: После успешного выполнения возвращает идентификатор созданного или отредактированного списка
        """

        params = locals()
        method_name = self._base_method + 'saveList'
        return self._call(method_name, params)

    def search(self, q: str = None, extended: str = None, count: str = None, latitude: str = None,
               longitude: str = None, start_time: str = None, end_time: str = None, start_from: str = None,
               fields: str = None) -> dict:
        """
        Возвращает результаты поиска по статусам. Новости возвращаются в порядке от более новых к более старым.

        :param q: поисковой запрос, например, "New Year".
        :param extended: 1, если необходимо получить информацию о пользователе или сообществе, разместившем
            запись. По умолчанию: 0.
        :param count: указывает, какое максимальное число записей следует возвращать. Обратите внимание — даже
            при использовании параметра offset для получения информации доступны только первые 1000 результатов.
        :param latitude: географическая широта точки, в радиусе от которой необходимо производить поиск, заданная
            в градусах (от -90 до 90).
        :param longitude: географическая долгота точки, в радиусе от которой необходимо производить поиск,
            заданная в градусах (от -180 до 180).
        :param start_time: время в формате unixtime, начиная с которого следует получить новости для текущего
            пользователя. Если параметр не задан, то он считается равным значению времени, которое было сутки назад.
        :param end_time: время в формате unixtime, до которого следует получить новости для текущего
            пользователя. Если параметр не задан, то он считается равным текущему времени.
        :param start_from: Идентификатор, необходимый для получения следующей страницы результатов. Значение,
            необходимое для передачи в этом параметре, возвращается в поле ответа next_from.
        :param fields: список дополнительных полей для профилей и групп, которые необходимо вернуть. См. описание
            полей объекта user и описание полей объекта group.  Обратите внимание, этот параметр учитывается только
            при extended=1.

        :return: В случае успеха возвращает общее количество записей и массив объектов, каждый из которых
            содержит поля:   id — локальный идентификатор записи (для конкретного владельца);  owner_id —
            идентификатор владельца стены, на которой размещена запись. Если стена принадлежит сообществу, то данный
            параметр равен -gid (идентификатор сообщества со знаком минус);  from_id — идентификатор автора записи;
            date — время публикации записи в формате unixtime;  text — текст записи;  comments — содержит информацию
            о количестве комментариев к записи. Для Desktop-приложений дополнительно содержит следующую информацию:
            может ли текущий пользователь добавить комментарии к записи;   likes — содержит информацию о числе людей,
            которым понравилась данная запись. Для Desktop-приложений дополнительно содержит следующую информацию:
            понравилась ли запись текущему пользователю;  может ли текущий пользователь добавить запись в спиcок Мне
            нравится;  может ли текущий пользователь опубликовать у себя запись.   attachments — находится в записях
            со стен и содержит массив объектов, которые прикреплены к текущей новости (фотография, ссылка и т.п.).
            Более подробная информация представлена на странице описания поля attachments.  geo — находится в записях
            со стен, в которых имеется информация о местоположении, содержит поля:   type — тип отметки;  coordinates
            — географические координаты места;  place — объект с полями:   pid — идентификатор места;  title —
            название места;  latitude — географическая широта;  longitude — географическая долгота;  created — дата
            добавления;  icon — значок места;  type — тип места;  address — строка с указанием адреса места в городе;
            country — идентификатор страны;  city — идентификатор города;   showmap — данный параметр указывается,
            если местоположение является прикреплённой картой.    В случае, если передан параметр extended,
            дополнительно будут переданы поля profiles и groups, содержащие информацию о пользователях и сообществах.
            Каждый из объектов в массиве profiles содержит следующие поля:   id — идентификатор пользователя;
            first_name — имя пользователя;  last_name — фамилия пользователя;  photo — адрес фотографии пользователя
            размером 50x50px;  photo_medium_rec — адрес фотографии пользователя размером 100x100px;  screen_name —
            короткий адрес страницы пользователя (например, andrew или id6492).   Каждый из объектов в массиве groups
            содержит следующие поля:   id — идентификатор сообщества;  name — название сообщества;  is_closed — флаг,
            определяющий является ли группа закрытой;  photo — адрес логотипа группы шириной 50px;  photo_medium —
            адрес логотипа группы шириной 100px;  photo_big — адрес логотипа группы шириной 200px;  screen_name —
            короткий адрес страницы сообщества (например, apiclub или club1)
        """

        params = locals()
        method_name = self._base_method + 'search'
        return self._call(method_name, params)

    def unignoreItem(self, type: str = None, owner_id: str = None, item_id: str = None) -> dict:
        """
        Позволяет вернуть ранее скрытый объект в ленту новостей.

        :param type: Тип объекта. Возможные значения:   wall — запись на стене;  tag — отметка на фотографии;
            profilephoto — фотография профиля;  video — видеозапись;  photo — фотография;  audio — аудиозапись.
        :param owner_id: Идентификатор владельца объекта (пользователь или сообщество). Обратите внимание,
            идентификатор сообщества в параметре owner_id необходимо указывать со знаком "-" — например, owner_id=-1
            соответствует идентификатору сообщества ВКонтакте API (club1)
        :param item_id: Идентификатор объекта.

        :return: В результате успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'unignoreItem'
        return self._call(method_name, params)

    def unsubscribe(self, type: str = None, owner_id: str = None, item_id: str = None) -> dict:
        """
        Отписывает текущего пользователя от комментариев к заданному объекту.

        :param type: тип объекта, от комментариев к которому необходимо отписаться.  Возможные типы: post —
            запись на стене пользователя или группы; photo — фотография; video — видеозапись; topic — обсуждение;
            note — заметка; market — товар.
        :param owner_id: идентификатор владельца объекта.
        :param item_id: идентификатор объекта.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'unsubscribe'
        return self._call(method_name, params)



from ApiMethod import ApiMethod


class Utils(ApiMethod):
    def __init__(self, access_token, v, session, calls_per_second):
        super(Utils, self).__init__(access_token, v, session, calls_per_second)
        self._base_method = 'utils.'

    def checkLink(self, url: str = None) -> dict:
        """
        Возвращает информацию о том, является ли внешняя ссылка заблокированной на сайте ВКонтакте.

        :param url: внешняя ссылка, которую необходимо проверить.  Например, http://google.com

        :return: После успешного выполнения возвращает объект, который содержит следующие поля:    status
            (string) — статус ссылки. Возможные значения:   not_banned – ссылка не заблокирована;  banned – ссылка
            заблокирована;  processing – ссылка проверяется, необходимо выполнить повторный запрос через несколько
            секунд.   link (string) — исходная ссылка (url) либо полная ссылка (если в url была передана сокращенная
            ссылка)
        """

        params = locals()
        method_name = self._base_method + 'checkLink'
        return self._call(method_name, params)

    def deleteFromLastShortened(self, key: str = None) -> dict:
        """
        Удаляет сокращенную ссылку из списка пользователя.

        :param key: сокращенная ссылка (часть URL после "vk.cc/").

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'deleteFromLastShortened'
        return self._call(method_name, params)

    def getLastShortenedLinks(self, count: str = None, offset: str = None) -> dict:
        """
        Получает список сокращенных ссылок для текущего пользователя.

        :param count: количество ссылок, которые необходимо получить.
        :param offset: сдвиг для получения определенного подмножества ссылок.

        :return: Возвращает количество ссылок в поле count (integer) и массив объектов items, описывающих ссылки.
            Каждый из объектов содержит следующие поля:   timestamp (integer) — время создания ссылки в Unixtime;
            url (string) — URL ссылки до сокращения;  short_url (string) — сокращенный URL;  key (string) —
            содержательная часть (символы после "vk.cc");  views (integer) — число переходов;  access_key (string) —
            ключ доступа к приватной статистике
        """

        params = locals()
        method_name = self._base_method + 'getLastShortenedLinks'
        return self._call(method_name, params)

    def getLinkStats(self, key: str = None, source: str = None, access_key: str = None, interval: str = None,
                     intervals_count: str = None, extended: str = None) -> dict:
        """
        Возвращает статистику переходов по сокращенной ссылке.

        :param key: сокращенная ссылка (часть URL после "vk.cc/").
        :param source:
        :param access_key: ключ доступа к приватной статистике ссылки.
        :param interval: единица времени для подсчета статистики. Возможные значения:   hour — час;  day — день;
            week — неделя;  month — месяц;  forever — все время с момента создания ссылки.
        :param intervals_count: длительность периода для получения статистики в выбранных единицах (из параметра
            interval).
        :param extended: 1 — возвращать расширенную статистику (пол/возраст/страна/город), 0 — возвращать только
            количество переходов.

        :return: Возвращает объект, содержащий поле key с входным параметром key и массив stats с данными о
            статистике. Каждый объект в массиве stats содержит поле timestamp с указанием времени начала отсчета,
            общее число переходов views и массивы, описывающие половозрастную/геостатистику: sex_age, countries,
            cities.  Каждый объект в массиве sex_age содержит следующие поля:   age_range (string) — обозначение
            возраста;  female (integer) — число переходов пользователей женского пола;  male (integer) — число
            переходов пользователей мужского пола;   Каждый объект в массиве countries (cities) содержит следующие
            поля:   country_id (city_id) (integer) — идентификатор страны (города);  views (integer) — число
            переходов из этой страны (города)
        """

        params = locals()
        method_name = self._base_method + 'getLinkStats'
        return self._call(method_name, params)

    def getServerTime(self) -> dict:
        """
        Возвращает текущее время на сервере ВКонтакте в unixtime.

        :return: Возвращает число, соответствующее времени в unixtime
        """

        params = locals()
        method_name = self._base_method + 'getServerTime'
        return self._call(method_name, params)

    def getShortLink(self, url: str = None, private: str = None) -> dict:
        """
        Позволяет получить URL, сокращенный с помощью vk.cc.

        :param url: URL, для которого необходимо получить сокращенный вариант.
        :param private: 1 — статистика ссылки приватная. 0 — статистика ссылки общедоступная.

        :return: Возвращает объект, содержащий следующие поля:   short_url (string) — сокращённая ссылка.
            access_key (string) — ключ для доступа к приватной статистике ссылки;  key (string) — содержательная
            часть ссылки (после "vk.cc");  url (string) — оригинальный URL
        """

        params = locals()
        method_name = self._base_method + 'getShortLink'
        return self._call(method_name, params)

    def resolveScreenName(self, screen_name: str = None) -> dict:
        """
        Определяет тип объекта (пользователь, сообщество, приложение) и его идентификатор по короткому имени
        screen_name.

        :param screen_name: короткое имя пользователя, группы или приложения. Например, apiclub, andrew или
            rules_of_war.

        :return: После успешного выполнения возвращает объект, который содержит следующие поля:   type (string) —
            тип объекта. Возможные значения:   user — пользователь;  group — сообщество;  application — приложение.
            object_id (integer)— идентификатор объекта.   Если короткое имя screen_name не занято, то будет возвращён
            пустой объект
        """

        params = locals()
        method_name = self._base_method + 'resolveScreenName'
        return self._call(method_name, params)



from typing import List, Dict, Optional, Union
import time


class ApiMethod:
    def __init__(self, access_token, v, session, calls_per_second):
        self._session = session
        self._calls_per_second = calls_per_second
        self._required_params = {
            'v': v,
            'access_token': access_token
        }

    def _call(self, method_name: str, params: dict) -> Union[dict, int, list]:
        url = 'https://api.vk.com/method/{}'.format(method_name)
        params.update(self._required_params)
        params.pop('self')
        params = {p: params[p] for p in params if params[p]}
        time_start = time.time()
        r = self._session.post(url, params=params)
        delay = 1 / (self._calls_per_second - 0.2) - (time.time() - time_start)
        if delay > 0:
            time.sleep(delay)
        try:
            r = r.json()['response']
        except Exception as e:
            print(r.json())
            raise e
        return r



from ApiMethod import ApiMethod


class Users(ApiMethod):
    def __init__(self, access_token, v, session, calls_per_second):
        super(Users, self).__init__(access_token, v, session, calls_per_second)
        self._base_method = 'users.'

    def get(self, user_ids: str = None, fields: str = None, name_case: str = None) -> dict:
        """
        Возвращает расширенную информацию о пользователях.

        :param user_ids: перечисленные через запятую идентификаторы пользователей или их короткие имена
            (screen_name). По умолчанию — идентификатор текущего пользователя.
        :param fields: список дополнительных полей профилей, которые необходимо вернуть. См. подробное описание.
            Доступные значения: photo_id, verified, sex, bdate, city, country, home_town, has_photo, photo_50,
            photo_100, photo_200_orig, photo_200, photo_400_orig, photo_max, photo_max_orig, online, domain,
            has_mobile, contacts, site, education, universities, schools, status, last_seen, followers_count,
            common_count, occupation, nickname, relatives, relation, personal, connections, exports, activities,
            interests, music, movies, tv, books, games, about, quotes, can_post, can_see_all_posts, can_see_audio,
            can_write_private_message, can_send_friend_request, is_favorite, is_hidden_from_feed, timezone,
            screen_name, maiden_name, crop_photo, is_friend, friend_status, career, military, blacklisted,
            blacklisted_by_me, can_be_invited_group.
        :param name_case: падеж для склонения имени и фамилии пользователя. Возможные значения: именительный –
            nom, родительный – gen, дательный – dat, винительный – acc, творительный – ins, предложный – abl. По
            умолчанию nom.

        :return: После успешного выполнения возвращает массив объектов пользователей
        """

        params = locals()
        method_name = self._base_method + 'get'
        return self._call(method_name, params)

    def getFollowers(self, user_id: str = None, offset: str = None, count: str = None, fields: str = None,
                     name_case: str = None) -> dict:
        """
        Возвращает список идентификаторов пользователей, которые являются подписчиками пользователя.

        :param user_id: идентификатор пользователя.
        :param offset: смещение, необходимое для выборки определенного подмножества подписчиков.
        :param count: количество подписчиков, информацию о которых нужно получить.
        :param fields: список дополнительных полей профилей, которые необходимо вернуть. См. подробное описание.
            Доступные значения: photo_id, verified, sex, bdate, city, country, home_town, has_photo, photo_50,
            photo_100, photo_200_orig, photo_200, photo_400_orig, photo_max, photo_max_orig, online, lists, domain,
            has_mobile, contacts, site, education, universities, schools, status, last_seen, followers_count,
            common_count, occupation, nickname, relatives, relation, personal, connections, exports, wall_comments,
            activities, interests, music, movies, tv, books, games, about, quotes, can_post, can_see_all_posts,
            can_see_audio, can_write_private_message, can_send_friend_request, is_favorite, is_hidden_from_feed,
            timezone, screen_name, maiden_name, crop_photo, is_friend, friend_status, career, military, blacklisted,
            blacklisted_by_me.
        :param name_case: падеж для склонения имени и фамилии пользователя. Возможные значения: именительный –
            nom, родительный – gen, дательный – dat, винительный – acc, творительный – ins, предложный – abl. По
            умолчанию nom.

        :return: После успешного выполнения возвращает объект, содержащий число результатов в поле count и массив
            объектов user в поле items.  Идентификаторы пользователей в списке отсортированы в порядке убывания
            времени их добавления
        """

        params = locals()
        method_name = self._base_method + 'getFollowers'
        return self._call(method_name, params)

    def getSubscriptions(self, user_id: str = None, extended: str = None, offset: str = None, count: str = None,
                         fields: str = None) -> dict:
        """
        Возвращает список идентификаторов пользователей и публичных страниц, которые входят в список подписок
        пользователя.

        :param user_id: идентификатор пользователя, подписки которого необходимо получить.
        :param extended: 1 – возвращает объединенный список, содержащий объекты group и user вместе. 0 –
            возвращает список идентификаторов групп и пользователей отдельно. (по умолчанию)
        :param offset: смещение необходимое для выборки определенного подмножества подписок. Этот параметр
            используется только если передан extended=1.
        :param count: количество подписок, которые необходимо вернуть. Этот параметр используется только если
            передан extended=1.
        :param fields: список дополнительных полей для объектов user и group, которые необходимо вернуть.

        :return: После успешного выполнения возвращает объекты users и groups, каждый из которых содержит поле
            count — количество результатов и items — список идентификаторов пользователей или публичных страниц, на
            которые подписан текущий пользователь (из раздела «Интересные страницы»).  Если был задан параметр
            extended=1, возвращает объединенный массив объектов group и user в поле items, а также общее число
            результатов в поле count
        """

        params = locals()
        method_name = self._base_method + 'getSubscriptions'
        return self._call(method_name, params)

    def report(self, user_id: str = None, type: str = None, comment: str = None) -> dict:
        """
        Позволяет пожаловаться на пользователя.

        :param user_id: идентификатор пользователя, на которого нужно подать жалобу.
        :param type: тип жалобы, может принимать следующие значения:   porn — порнография;  spam — рассылка
            спама;  insult — оскорбительное поведение;  advertisеment — рекламная страница, засоряющая поиск.
        :param comment: комментарий к жалобе на пользователя.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'report'
        return self._call(method_name, params)

    def search(self, q: str = None, sort: str = None, offset: str = None, count: str = None, fields: str = None,
               city: str = None, country: str = None, hometown: str = None, university_country: str = None,
               university: str = None, university_year: str = None, university_faculty: str = None,
               university_chair: str = None, sex: str = None, status: str = None, age_from: str = None,
               age_to: str = None, birth_day: str = None, birth_month: str = None, birth_year: str = None,
               online: str = None, has_photo: str = None, school_country: str = None, school_city: str = None,
               school_class: str = None, school: str = None, school_year: str = None, religion: str = None,
               company: str = None, position: str = None, group_id: str = None, from_list: str = None) -> dict:
        """
        Возвращает список пользователей в соответствии с заданным критерием поиска.

        :param q:  поискового запроса. Например, Вася Бабич.
        :param sort: сортировка результатов. Возможные значения:   1 — по дате регистрации;  0 — по популярности.
        :param offset: смещение относительно первого найденного пользователя для выборки определенного
            подмножества.
        :param count: количество возвращаемых пользователей. Обратите внимание — даже при использовании параметра
            offset для получения информации доступны только первые 1000 результатов.
        :param fields: список дополнительных полей профилей, которые необходимо вернуть. См. подробное описание.
            Доступные значения: photo_id, verified, sex, bdate, city, country, home_town, has_photo, photo_50,
            photo_100, photo_200_orig, photo_200, photo_400_orig, photo_max, photo_max_orig, online, lists, domain,
            has_mobile, contacts, site, education, universities, schools, status, last_seen, followers_count,
            common_count, occupation, nickname, relatives, relation, personal, connections, exports, wall_comments,
            activities, interests, music, movies, tv, books, games, about, quotes, can_post, can_see_all_posts,
            can_see_audio, can_write_private_message, can_send_friend_request, is_favorite, is_hidden_from_feed,
            timezone, screen_name, maiden_name, crop_photo, is_friend, friend_status, career, military, blacklisted,
            blacklisted_by_me
        :param city: идентификатор города.
        :param country: идентификатор страны.
        :param hometown: название города строкой.
        :param university_country: идентификатор страны, в которой пользователи закончили ВУЗ.
        :param university: идентификатор ВУЗа.
        :param university_year: год окончания ВУЗа.
        :param university_faculty: идентификатор факультета.
        :param university_chair: идентификатор кафедры.
        :param sex: пол. Возможные значения:   1 — женщина;  2 — мужчина;  0 — любой (по умолчанию).
        :param status: семейное положение. Возможные значения:   1 — не женат (не замужем);  2 — встречается;  3
            — помолвлен(-а);  4 — женат (замужем);  5 — всё сложно;  6 — в активном поиске;  7 — влюблен(-а);  8 — в
            гражданском браке.
        :param age_from: возраст, от.
        :param age_to: возраст, до.
        :param birth_day: день рождения.
        :param birth_month: месяц рождения.
        :param birth_year: год рождения.
        :param online: учитывать ли статус «онлайн». Возможные значения:   1 — искать только пользователей
            онлайн;  0 — искать по всем пользователям.
        :param has_photo: учитывать ли наличие фото. Возможные значения:   1 — искать только пользователей с
            фотографией;  0 — искать по всем пользователям.
        :param school_country: идентификатор страны, в которой пользователи закончили школу.
        :param school_city: идентификатор города, в котором пользователи закончили школу.
        :param school_class: буква класса.
        :param school: идентификатор школы, которую закончили пользователи.
        :param school_year: год окончания школы.
        :param religion: религиозные взгляды.
        :param company: название компании, в которой работают пользователи.
        :param position: название должности.
        :param group_id: идентификатор группы, среди пользователей которой необходимо проводить поиск.
        :param from_list: Разделы среди которых нужно осуществить поиск, перечисленные через запятую. Возможные
            значения:   friends — искать среди друзей;  subscriptions — искать среди друзей и подписок пользователя.

        :return: После успешного выполнения возвращает объект, содержащий число результатов в поле count и массив
            объектов, описывающих пользователей в поле items
        """

        params = locals()
        method_name = self._base_method + 'search'
        return self._call(method_name, params)



from ApiMethod import ApiMethod
from typing import List, Union, Dict
from vk_objects import User


class Friends(ApiMethod):
    def __init__(self, access_token, v, session, calls_per_second):
        super(Friends, self).__init__(access_token, v, session, calls_per_second)
        self._base_method = 'friends.'

    def add(self, user_id: str = None, text: str = None, follow: str = None) -> dict:
        """
        Одобряет или создает заявку на добавление в друзья.

        :param user_id: идентификатор пользователя, которому необходимо отправить заявку, либо заявку от которого
            необходимо одобрить.
        :param text: текст сопроводительного сообщения для заявки на добавление в друзья. Максимальная длина
            сообщения — 500 символов.
        :param follow: 1, если необходимо отклонить входящую заявку (оставить пользователя в подписчиках).

        :return: После успешного выполнения возвращает одно из следующих значений:   1 — заявка на добавление
            данного пользователя в друзья отправлена;  2 — заявка на добавление в друзья от данного пользователя
            одобрена;  4 — повторная отправка заявки
        """

        params = locals()
        method_name = self._base_method + 'add'
        return self._call(method_name, params)

    def addList(self, name: str = None, user_ids: str = None) -> dict:
        """
        Создает новый список друзей у текущего пользователя.

        :param name: название создаваемого списка друзей.
        :param user_ids: идентификаторы пользователей, которых необходимо поместить в созданный список.

        :return: После успешного выполнения возвращает идентификатор (list_id) созданного списка друзей
        """

        params = locals()
        method_name = self._base_method + 'addList'
        return self._call(method_name, params)

    def areFriends(self, user_ids: str = None, need_sign: str = None) -> dict:
        """
        Возвращает информацию о том, добавлен ли текущий пользователь в друзья у указанных пользователей.

        :param user_ids: идентификаторы пользователей, статус дружбы с которыми нужно проверить.
        :param need_sign: 1 – необходимо вернуть поле sign которое равно:
            md5("{id}_{user_id}_{friends_status}_{application_secret}"), где id - это идентификатор пользователя, для
            которого выполняется запрос.  и позволяет на сервере убедиться что данные не были подделаны на клиенте.
            0 – поле sign возвращать не нужно.

        :return: После успешного выполнения возвращает массив объектов, каждый из которых содержит следующие
            поля:   user_id — идентификатор пользователя (из числа переданных в параметре user_ids);  friend_status —
            статус дружбы с пользователем:   0 – пользователь не является другом,  1 – отправлена заявка/подписка
            пользователю,  2 – имеется входящая заявка/подписка от пользователя,  3 – пользователь является другом;
            request_message — текст сообщения, прикрепленного к заявке в друзья (если есть).  read_state — статус
            заявки (0 — не просмотрена, 1 — просмотрена), возвращается только если friend_status = 2
        """

        params = locals()
        method_name = self._base_method + 'areFriends'
        return self._call(method_name, params)

    def delete(self, user_id: str = None) -> dict:
        """
        Удаляет пользователя из списка друзей или отклоняет заявку в друзья.

        :param user_id: идентификатор пользователя, которого необходимо удалить из списка друзей, либо заявку от
            которого необходимо отклонить.

        :return: После успешного выполнения начиная с версии 5.28 возвращается объект с полями:   success —
            удалось успешно удалить друга  friend_deleted — был удален друг  out_request_deleted — отменена исходящая
            заявка  in_request_deleted — отклонена входящая заявка  suggestion_deleted — отклонена рекомендация друга
            Для версии 5.27 и более старых возвращает одно из следующих значений:   1 — пользователь удален из списка
            друзей;  2 — заявка на добавление в друзья данного пользователя отклонена (входящая или исходящая);  3 —
            рекомендация добавить в друзья данного пользователя удалена
        """

        params = locals()
        method_name = self._base_method + 'delete'
        return self._call(method_name, params)

    def deleteAllRequests(self) -> dict:
        """
        Отмечает все входящие заявки на добавление в друзья как просмотренные.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'deleteAllRequests'
        return self._call(method_name, params)

    def deleteList(self, list_id: str = None) -> dict:
        """
        Удаляет существующий список друзей текущего пользователя.

        :param list_id: идентификатор списка друзей, который необходимо удалить.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'deleteList'
        return self._call(method_name, params)

    def edit(self, user_id: str = None, list_ids: str = None) -> dict:
        """
        Редактирует списки друзей для выбранного друга.

        :param user_id: идентификатор пользователя (из числа друзей), для которого необходимо отредактировать
            списки друзей.
        :param list_ids: идентификаторы списков друзей, в которые нужно добавить пользователя.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'edit'
        return self._call(method_name, params)

    def editList(self, name: str = None, list_id: str = None, user_ids: str = None, add_user_ids: str = None,
                 delete_user_ids: str = None) -> dict:
        """
        Редактирует существующий список друзей текущего пользователя.

        :param name: название списка друзей.
        :param list_id: идентификатор списка друзей.
        :param user_ids: идентификаторы пользователей, включенных в список.
        :param add_user_ids: идентификаторы пользователей, которых необходимо добавить в список. (в случае если
            не передан user_ids)
        :param delete_user_ids: идентификаторы пользователей, которых необходимо изъять из списка. (в случае если
            не передан user_ids)

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'editList'
        return self._call(method_name, params)

    def get(self, user_id: str = None, order: str = None, list_id: str = None, count: str = None, offset: str = None,
            fields: str = None, name_case: str = None, ref: str = None) -> dict:
        """
        Возвращает список идентификаторов друзей пользователя или расширенную информацию о друзьях пользователя (при
        использовании параметра fields).

        :param user_id: идентификатор пользователя, для которого необходимо получить список друзей. Если параметр
            не задан, то считается, что он равен идентификатору текущего пользователя (справедливо для вызова с
            передачей access_token).
        :param order: порядок, в котором нужно вернуть список друзей. Допустимые значения:   hints — сортировать
            по рейтингу, аналогично тому, как друзья сортируются в разделе Мои друзья (Это значение доступно только
            для Standalone-приложений с ключом доступа, полученным по схеме Implicit Flow.).  random — возвращает
            друзей в случайном порядке.  mobile — возвращает выше тех друзей, у которых установлены мобильные
            приложения.  name — сортировать по имени. Данный тип сортировки работает медленно, так как сервер будет
            получать всех друзей а не только указанное количество count. (работает только при переданном параметре
            fields).   По умолчанию список сортируется в порядке возрастания идентификаторов пользователей.
        :param list_id: идентификатор списка друзей, полученный методом friends.getLists, друзей из которого
            необходимо получить. Данный параметр учитывается, только когда параметр user_id равен идентификатору
            текущего пользователя.  Этот параметр доступен только для Standalone-приложений с ключом доступа,
            полученным по схеме Implicit Flow.
        :param count: количество друзей, которое нужно вернуть.
        :param offset: смещение, необходимое для выборки определенного подмножества друзей.
        :param fields: список дополнительных полей, которые необходимо вернуть.  Доступные значения: nickname,
            domain, sex, bdate, city, country, timezone, photo_50, photo_100, photo_200_orig, has_mobile, contacts,
            education, online, relation, last_seen, status, can_write_private_message, can_see_all_posts, can_post,
            universities
        :param name_case: падеж для склонения имени и фамилии пользователя. Возможные значения: именительный –
            nom, родительный – gen, дательный – dat, винительный – acc, творительный – ins, предложный – abl. По
            умолчанию nom.
        :param ref:

        :return: После успешного выполнения возвращает список идентификаторов (id) друзей пользователя, если
            параметр fields не использовался.  При использовании параметра fields возвращает список объектов
            пользователей, но не более 5000
        """

        params = locals()
        method_name = self._base_method + 'get'
        return self._call(method_name, params)

    def getAppUsers(self) -> dict:
        """
        Возвращает список идентификаторов друзей текущего пользователя, которые установили данное приложение.

        :return: После успешного выполнения возвращает список идентификаторов (id) друзей текущего пользователя,
            установивших приложение
        """

        params = locals()
        method_name = self._base_method + 'getAppUsers'
        return self._call(method_name, params)

    def getByPhones(self, phones: str = None, fields: str = None) -> dict:
        """
        Возвращает список друзей пользователя, у которых завалидированные или указанные в профиле телефонные номера
        входят в заданный список.

        :param phones: список телефонных номеров в формате MSISDN, разделеннных запятыми. Например
            +79219876543,+79111234567 Максимальное количество номеров в списке — 1000.
        :param fields: список дополнительных полей, которые необходимо вернуть.  Доступные значения: nickname,
            screen_name, sex, bdate, city, country, timezone, photo_50, photo_100, photo_200_orig, has_mobile,
            contacts, education, online, counters, relation, last_seen, status, can_write_private_message,
            can_see_all_posts, can_post, universities.

        :return: После успешного выполнения возвращает список объектов пользователей с дополнительным полем
            phone, в котором содержится номер из списка заданных для поиска номеров
        """

        params = locals()
        method_name = self._base_method + 'getByPhones'
        return self._call(method_name, params)

    def getLists(self, user_id: str = None, return_system: str = None) -> dict:
        """
        Возвращает список меток друзей пользователя.

        :param user_id: идентификатор пользователя.
        :param return_system: возвращать ли системный список публичных меток друзей пользователя.

        :return: После успешного выполнения возвращает список объектов, каждый из которых содержит следующие
            поля:   name — название списка друзей;  id — идентификатор списка друзей
        """

        params = locals()
        method_name = self._base_method + 'getLists'
        return self._call(method_name, params)

    def getMutual(self, source_uid: str = None, target_uid: str = None, target_uids: str = None, order: str = None,
                  count: str = None, offset: str = None) -> dict:
        """
        Возвращает список идентификаторов общих друзей между парой пользователей.

        :param source_uid: идентификатор пользователя, чьи друзья пересекаются с друзьями пользователя с
            идентификатором target_uid. Если параметр не задан, то считается, что source_uid равен идентификатору
            текущего пользователя.
        :param target_uid: идентификатор пользователя, с которым необходимо искать общих друзей.
        :param target_uids: список идентификаторов пользователей, с которыми необходимо искать общих друзей.
        :param order: порядок, в котором нужно вернуть список общих друзей. Допустимые значения: random -
            возвращает друзей в случайном порядке. По умолчанию — в порядке возрастания идентификаторов.
        :param count: количество общих друзей, которое нужно вернуть. (по умолчанию – все общие друзья)
        :param offset: смещение, необходимое для выборки определенного подмножества общих друзей.

        :return: После успешного выполнения возвращает список идентификаторов (id) общих друзей между
            пользователями с идентификаторами source_uid и target_uid
        """

        params = locals()
        method_name = self._base_method + 'getMutual'
        return self._call(method_name, params)

    def getOnline(self, user_id: str = None, list_id: str = None, online_mobile: str = None, order: str = None,
                  count: str = None, offset: str = None) -> dict:
        """
        Возвращает список идентификаторов друзей пользователя, находящихся на сайте.

        :param user_id: идентификатор пользователя, для которого необходимо получить список друзей онлайн. Если
            параметр не задан, то считается, что он равен идентификатору текущего пользователя.
        :param list_id: идентификатор списка друзей. Если параметр не задан, возвращается информация обо всех
            друзьях, находящихся на сайте.
        :param online_mobile: 1 — будет возвращено дополнительное поле online_mobile.  По умолчанию — 0.
        :param order: порядок, в котором нужно вернуть список друзей, находящихся на сайте. Допустимые значения:
            random - возвращает друзей в случайном порядке, hints - сортировать по рейтингу, аналогично тому, как
            друзья сортируются в разделе Мои друзья (данный параметр доступен только для Desktop-приложений).  По
            умолчанию список сортируется в порядке возрастания идентификаторов пользователей.
        :param count: количество друзей онлайн, которое нужно вернуть. (по умолчанию – все друзья онлайн)
        :param offset: смещение, необходимое для выборки определенного подмножества друзей онлайн.

        :return: После успешного выполнения возвращает список идентификаторов (id) друзей, находящихся сейчас на
            сайте, у пользователя с идентификатором uid и входящих в список с идентификатором lid.  При использовании
            параметра online_mobile=1 также возвращается поле online_mobile, содержащее список идентификатор друзей,
            находящихся на сайте с мобильного устройства
        """

        params = locals()
        method_name = self._base_method + 'getOnline'
        return self._call(method_name, params)

    def getRecent(self, count: str = None) -> dict:
        """
        Возвращает список идентификаторов недавно добавленных друзей текущего пользователя.

        :param count: максимальное количество недавно добавленных друзей, которое необходимо получить.

        :return: После успешного выполнения возвращает отсортированный в антихронологическом порядке список
            идентификаторов (id) недавно добавленных друзей текущего пользователя
        """

        params = locals()
        method_name = self._base_method + 'getRecent'
        return self._call(method_name, params)

    def getRequests(self, offset: str = None, count: str = None, extended: str = None, need_mutual: str = None,
                    out: str = None, sort: str = None, need_viewed: str = None, suggested: str = None, ref: str = None,
                    fields: str = None) -> dict:
        """
        Возвращает информацию о полученных или отправленных заявках на добавление в друзья для текущего пользователя.

        :param offset: смещение, необходимое для выборки определенного подмножества заявок на добавление в
            друзья.
        :param count: максимальное количество заявок на добавление в друзья, которые необходимо получить (не
            более 1000).  По умолчанию — 100.
        :param extended: определяет, требуется ли возвращать в ответе сообщения от пользователей, подавших заявку
            на добавление в друзья. И отправителя рекомендации при suggested = 1.
        :param need_mutual: определяет, требуется ли возвращать в ответе список общих друзей, если они есть.
            Обратите внимание, что при использовании need_mutual будет возвращено не более 2 заявок.
        :param out: 0 — возвращать полученные заявки в друзья (по умолчанию), 1 — возвращать отправленные
            пользователем заявки.
        :param sort: 0 — сортировать по дате добавления, 1 — сортировать по количеству общих друзей. (Если out =
            1, этот параметр не учитывается).
        :param need_viewed: 0 - не возвращать просмотренные заявки, 1 — возвращать просмотренные заявки. (Если
            out = 1, данный параметр не учитывается).
        :param suggested: 1 — возвращать рекомендованных другими пользователями друзей, 0 — возвращать заявки в
            друзья (по умолчанию).
        :param ref:
        :param fields:

        :return:   Если не установлен параметр need_mutual, то в случае успеха возвращает отсортированный в
            антихронологическом порядке по времени подачи заявки список идентификаторов (id) пользователей (кому или
            от кого пришла заявка).     Если установлен параметр need_mutual, то в случае успеха возвращает
            отсортированный в антихронологическом порядке по времени подачи заявки массив объектов, содержащих
            информацию о заявках на добавление в друзья. Каждый из объектов содержит поле uid, являющийся
            идентификатором пользователя. При наличии общих друзей, в объекте будет содержаться поле mutual, в
            котором будет находиться список идентификаторов общих друзей
        """

        params = locals()
        method_name = self._base_method + 'getRequests'
        return self._call(method_name, params)

    def getSuggestions(self, filter: str = None, count: str = None, offset: str = None, fields: str = None,
                       name_case: str = None) -> dict:
        """
        Возвращает список профилей пользователей, которые могут быть друзьями текущего пользователя.

        :param filter: типы предлагаемых друзей, которые нужно вернуть, перечисленные через запятую.  Может
            принимать следующие значения:  mutual — пользователи, с которыми много общих друзей; По умолчанию будут
            возвращены все возможные друзья.
        :param count: количество рекомендаций, которое необходимо вернуть.
        :param offset: смещение, необходимое для выбора определённого подмножества списка.
        :param fields: список дополнительных полей, которые необходимо вернуть.  Доступные значения: nickname,
            screen_name, sex, bdate, city, country, timezone, photo_50, photo_100, photo_200_orig, has_mobile,
            contacts, education, online, counters, relation, last_seen, status, can_write_private_message,
            can_see_all_posts, can_post, universities
        :param name_case: падеж для склонения имени и фамилии пользователя. Возможные значения: именительный –
            nom, родительный – gen, дательный – dat, винительный – acc, творительный – ins, предложный – abl. По
            умолчанию nom.

        :return: После успешного выполнения возвращает список объектов пользователей с дополнительным полем
            found_with для пользователей, найденных через импорт контактов. Для некоторых пользователей, которые были
            найдены давно поле found_with может отсутствовать
        """

        params = locals()
        method_name = self._base_method + 'getSuggestions'
        return self._call(method_name, params)

    def search(self, user_id: str = None, q: str = None, fields: str = None, name_case: str = None, offset: str = None,
               count: str = None) -> dict:
        """
        Позволяет искать по списку друзей пользователей.

        :param user_id: идентификатор пользователя, по списку друзей которого необходимо произвести поиск.
        :param q:  запроса.
        :param fields: список дополнительных полей, которые необходимо вернуть.  Доступные значения: nickname,
            screen_name, sex, bdate, city, country, timezone, photo_50, photo_100, photo_200_orig, has_mobile,
            contacts, education, online, relation, last_seen, status, can_write_private_message, can_see_all_posts,
            can_post, universities, domain
        :param name_case: падеж для склонения имени и фамилии пользователя. Возможные значения: именительный –
            nom, родительный – gen, дательный – dat, винительный – acc, творительный – ins, предложный – abl. По
            умолчанию nom.
        :param offset: смещение, необходимое для выборки определенного подмножества друзей.
        :param count: количество друзей, которое нужно вернуть.

        :return: После успешного выполнения метод возвращает список объектов пользователей
        """

        params = locals()
        method_name = self._base_method + 'search'
        return self._call(method_name, params)



from ApiMethod import ApiMethod


class Execute(ApiMethod):
    def __init__(self, access_token, v, session, calls_per_second):
        super(Execute, self).__init__(access_token, v, session, calls_per_second)
        self._base_method = 'execute'

    def __call__(self, code):
        params = locals()
        return self._call(self._base_method, params)



from ApiMethod import ApiMethod


class Board(ApiMethod):
    def __init__(self, access_token, v, session, calls_per_second):
        super(Board, self).__init__(access_token, v, session, calls_per_second)
        self._base_method = 'board.'

    def addTopic(self, group_id: str = None, title: str = None, text: str = None, from_group: str = None,
                 attachments: str = None) -> dict:
        """
        Создает новую тему в списке обсуждений группы.

        :param group_id: идентификатор сообщества.
        :param title: название обсуждения.
        :param text: текст первого сообщения в обсуждении.
        :param from_group: 1 — тема будет создана от имени группы, 0 — тема будет создана от имени пользователя
            (по умолчанию).
        :param attachments: список объектов, приложенных к записи, в формате:
            <type><owner_id>_<media_id>,<type><owner_id>_<media_id>   <type> — тип медиа-приложения:   photo —
            фотография;  video — видеозапись ;  audio — аудиозапись;  doc — документ;   <owner_id> — идентификатор
            владельца медиа-приложения  <media_id> — идентификатор медиа-приложения.
            Например:photo100172_166443618,photo66748_265827614  Параметр является обязательным, если не задан
            параметр text.

        :return: В случае успеха возвращает идентификатор созданной темы
        """

        params = locals()
        method_name = self._base_method + 'addTopic'
        return self._call(method_name, params)

    def closeTopic(self, group_id: str = None, topic_id: str = None) -> dict:
        """
        Закрывает тему в списке обсуждений группы (в такой теме невозможно оставлять новые сообщения).

        :param group_id: идентификатор сообщества, в котором размещено обсуждение.
        :param topic_id: идентификатор обсуждения.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'closeTopic'
        return self._call(method_name, params)

    def createComment(self, group_id: str = None, topic_id: str = None, message: str = None, attachments: str = None,
                      from_group: str = None, sticker_id: str = None, guid: str = None) -> dict:
        """
        Добавляет новый комментарий в обсуждении.

        :param group_id: идентификатор сообщества, в котором находится обсуждение.
        :param topic_id: идентификатор темы, в которой необходимо оставить комментарий.
        :param message: текст комментария. Обязательный параметр, если не передано значение attachments.
        :param attachments: Список объектов, приложенных к комментарию и разделённых символом ",". Поле
            attachments представляется в формате: <type><owner_id>_<media_id>,<type><owner_id>_<media_id>  <type> —
            тип медиа-вложения: photo — фотография; video — видеозапись; audio — аудиозапись; doc — документ;
            <owner_id> — идентификатор владельца медиа-вложения; <media_id> — идентификатор медиа-вложения.
            Например: photo100172_166443618,photo66748_265827614
        :param from_group: 1 — сообщение будет опубликовано от имени группы, 0 — сообщение будет опубликовано от
            имени пользователя (по умолчанию).
        :param sticker_id: идентификатор стикера.
        :param guid: уникальный идентификатор, предназначенный для предотвращения повторной отправки одинакового
            комментария.

        :return: В случае успеха возвращает идентификатор созданного комментария
        """

        params = locals()
        method_name = self._base_method + 'createComment'
        return self._call(method_name, params)

    def deleteComment(self, group_id: str = None, topic_id: str = None, comment_id: str = None) -> dict:
        """
        Удаляет сообщение темы в обсуждениях сообщества.

        :param group_id: идентификатор сообщества.
        :param topic_id: идентификатор обсуждения.
        :param comment_id: идентификатор комментария в обсуждении.

        :return: После успешного выполнения, а также в том случае, если комментарий уже удален, возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'deleteComment'
        return self._call(method_name, params)

    def deleteTopic(self, group_id: str = None, topic_id: str = None) -> dict:
        """
        Удаляет тему в обсуждениях группы.

        :param group_id: идентификатор сообщества, в котором размещено обсуждение.
        :param topic_id: идентификатор обсуждения.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'deleteTopic'
        return self._call(method_name, params)

    def editComment(self, group_id: str = None, topic_id: str = None, comment_id: str = None, message: str = None,
                    attachments: str = None) -> dict:
        """
        Редактирует одно из сообщений в обсуждении сообщества.

        :param group_id: идентификатор сообщества, в котором размещено обсуждение.
        :param topic_id: идентификатор обсуждения.
        :param comment_id: идентификатор комментария в обсуждении.
        :param message: новый текст комментария (является обязательным, если не задан параметр attachments).
        :param attachments: новый список объектов, приложенных к комментарию и разделённых символом ",". Поле
            attachments представляется в формате: <type><owner_id>_<media_id>,<type><owner_id>_<media_id> <type> —
            тип медиа-вложения: photo — фотография  video — видеозапись  audio — аудиозапись  doc — документ
            <owner_id> — идентификатор владельца медиа-вложения  <media_id> — идентификатор медиа-вложения.
            Например: photo100172_166443618,photo66748_265827614 Параметр является обязательным, если не задан
            параметр message.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'editComment'
        return self._call(method_name, params)

    def editTopic(self, group_id: str = None, topic_id: str = None, title: str = None) -> dict:
        """
        Изменяет заголовок темы в списке обсуждений группы.

        :param group_id: идентификатор сообщества, в котором размещено обсуждение.
        :param topic_id: идентификатор обсуждения.
        :param title: новое название обсуждения.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'editTopic'
        return self._call(method_name, params)

    def fixTopic(self, group_id: str = None, topic_id: str = None) -> dict:
        """
        Закрепляет тему в списке обсуждений группы (такая тема при любой сортировке выводится выше остальных).

        :param group_id: идентификатор сообщества, в котором размещено обсуждение.
        :param topic_id: идентификатор обсуждения.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'fixTopic'
        return self._call(method_name, params)

    def getComments(self, group_id: str = None, topic_id: str = None, need_likes: str = None,
                    start_comment_id: str = None, offset: str = None, count: str = None, extended: str = None,
                    sort: str = None) -> dict:
        """
        Возвращает список сообщений в указанной теме.

        :param group_id: идентификатор сообщества, информацию об обсуждениях которого нужно получить.
        :param topic_id: идентификатор обсуждения.
        :param need_likes: 1 — будет возвращено дополнительное поле likes. По умолчанию поле likes не
            возвращается.
        :param start_comment_id: идентификатор комментария, начиная с которого нужно вернуть список (подробности
            см. ниже).
        :param offset: смещение, необходимое для выборки определенного подмножества сообщений.
        :param count: количество сообщений, которое необходимо получить (но не более 100). По умолчанию — 20.
        :param extended: Если указать в качестве этого параметра 1, то будет возвращена информация о
            пользователях, являющихся авторами сообщений. По умолчанию 0.
        :param sort: порядок сортировки комментариев: asc — хронологический desc — антихронологический

        :return: В случае успеха возвращает объект, содержащий поле items, поле poll, если к теме прикреплен
            опрос, а также поле profiles (если был указан параметр extended).  Поле items представляет собой массив,
            содержащий объекты, описывающие комментарии.  Если к теме был прикреплен опрос, возвращается поле poll
            следующего вида:   owner_id — идентификатор владельца опроса  poll_id — идентификатор опроса;  created —
            время создания опроса в формате unixtime;  is_closed — 1, если опрос закрыт (в нем больше нельзя
            принимать участие) или 0 в противном случае;  question — текст вопроса для опроса;  votes — общее
            количество ответивших пользователей;  answer_id — идентификатор ответа текущего пользователя (если
            текущий пользователь еще не отвечал в данном опросе, то содержит 0);  answers — массив, содержащий
            объекты с вариантами ответа на вопрос в опросе:   id — идентификатор ответа на вопрос;  text — текст
            ответа на вопрос;  votes — количество пользователей, проголосовавших за данный вариант ответа;  rate —
            рейтинг данного варианта ответа, выраженный в процентах.    В случае передачи параметра extended равным
            1, поле profiles содержит массив объектов user с информацией о данных пользователей, являющихся авторами
            сообщений.  Если был передан параметр start_comment_id, будет также возвращено поле real_offset –
            итоговое смещение данного подмножества комментариев (оно может быть отрицательным, если был указан
            отрицательный offset)
        """

        params = locals()
        method_name = self._base_method + 'getComments'
        return self._call(method_name, params)

    def getTopics(self, group_id: str = None, topic_ids: str = None, order: str = None, offset: str = None,
                  count: str = None, extended: str = None, preview: str = None, preview_length: str = None) -> dict:
        """
        Возвращает список тем в обсуждениях указанной группы.

        :param group_id: идентификатор сообщества, информацию об обсуждениях которого необходимо получить. Если
            сообщество закрытое или частное, для вызова метода потребуется право доступа groups.
        :param topic_ids: список идентификаторов тем, которые необходимо получить (не более 100). По умолчанию
            возвращаются все темы. Если указан данный параметр, игнорируются параметры order, offset и count
            (возвращаются все запрошенные темы в указанном порядке).
        :param order: Порядок, в котором необходимо вернуть список тем. Возможные значения:   1 — по убыванию
            даты обновления;  2 — по убыванию даты создания;  -1 — по возрастанию даты обновления;  -2 — по
            возрастанию даты создания.  По умолчанию темы возвращаются в порядке, установленном администратором
            группы. "Прилепленные" темы при любой сортировке возвращаются первыми в списке.
        :param offset: смещение, необходимое для выборки определенного подмножества тем.
        :param count: количество тем, которое необходимо получить (но не более 100). По умолчанию — 40.
        :param extended: Если указать в качестве этого параметра 1, то будет возвращена информация о
            пользователях, являющихся создателями тем или оставившими в них последнее сообщение. По умолчанию 0.
        :param preview: Набор флагов, определяющий, необходимо ли вернуть вместе с информацией о темах текст
            первых и последних сообщений в них. Является суммой флагов:   1 — вернуть первое сообщение в каждой теме
            (поле first_comment);  2 — вернуть последнее сообщение в каждой теме (поле last_comment). По умолчанию —
            0 (не возвращать текст сообщений).
        :param preview_length: Количество символов, по которому нужно обрезать первое и последнее сообщение.
            Укажите 0, если Вы не хотите обрезать сообщение. (по умолчанию — 90).

        :return: После успешного выполнения возвращает объект, содержащий следующие поля:  count integer число
            результатов. items array массив объектов, описывающих обсуждения. default_order integer тип сортировки
            обсуждений в сообществе. Возможные значения:   1 — по убыванию даты обновления;  2 — по убыванию даты
            создания;  -1 — по возрастанию даты обновления;  -2 — по возрастанию даты создания. can_add_topics
            integer, [0,1] информация о том, может ли текущий пользователь создать обсуждение в сообществе. Возможные
            значения:   0 — не может;  1 — может. profiles array (только для extended = 1). Массив объектов,
            описывающих пользователей. Каждый из объектов содержит базовые поля, а также поля sex, photo_50,
            photo_100, online и type (= profile)
        """

        params = locals()
        method_name = self._base_method + 'getTopics'
        return self._call(method_name, params)

    def openTopic(self, group_id: str = None, topic_id: str = None) -> dict:
        """
        Открывает ранее закрытую тему (в ней станет возможно оставлять новые сообщения).

        :param group_id: идентификатор сообщества, в котором размещено обсуждение.
        :param topic_id: идентификатор обсуждения.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'openTopic'
        return self._call(method_name, params)

    def restoreComment(self, group_id: str = None, topic_id: str = None, comment_id: str = None) -> dict:
        """
        Восстанавливает удаленное сообщение темы в обсуждениях группы.

        :param group_id: идентификатор сообщества, в котором размещено обсуждение.
        :param topic_id: идентификатор обсуждения.
        :param comment_id: идентификатор комментария.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'restoreComment'
        return self._call(method_name, params)

    def unfixTopic(self, group_id: str = None, topic_id: str = None) -> dict:
        """
        Отменяет прикрепление темы в списке обсуждений группы (тема будет выводиться согласно выбранной сортировке).

        :param group_id: идентификатор сообщества, в котором размещено обсуждение.
        :param topic_id: идентификатор обсуждения.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'unfixTopic'
        return self._call(method_name, params)



from ApiMethod import ApiMethod


class Leads(ApiMethod):
    def __init__(self, access_token, v, session, calls_per_second):
        super(Leads, self).__init__(access_token, v, session, calls_per_second)
        self._base_method = 'leads.'

    def checkUser(self, lead_id: str = None, test_result: str = None, test_mode: str = None, auto_start: str = None,
                  age: str = None, country: str = None) -> dict:
        """
        Проверяет, доступна ли рекламная акция пользователю.

        :param lead_id: Идентификатор рекламной акции
        :param test_result: При использовании тестового режима функция вернёт result, соответствующий значению
            этого параметра.
        :param test_mode: 1 -- включить тестовый режим;  0 -- включить боевой режим.
        :param auto_start: Автоматический старт акции при успешной проверке. Доступно по согласованию с
            администрацией.
        :param age: Возраст пользователя.
        :param country: Двухбуквенный код страны пользователя (ISO 3166-1 alpha-2, также известный как ISO2).

        :return: Возвращает объект, содержащий поля:   result — признак того, может ли пользователь начать акцию
            (true/false), а также, в случае auto_start=1, признак успешного старта акции,  reason — в случае
            result=false, описание причины, по которой пользователь не может начать акцию,  start_link — в случае
            result=true и auto_start=0, ссылка, по которой должен перейти пользователь для начала акции.  sid — в
            случае result=true и auto_start=1, идентификатор сессии начатой акции
        """

        params = locals()
        method_name = self._base_method + 'checkUser'
        return self._call(method_name, params)

    def complete(self, vk_sid: str = None, secret: str = None, comment: str = None) -> dict:
        """
        Завершает начатую пользователем рекламную акцию, используя сессию и секретный ключ.

        :param vk_sid: cессия, полученная GET параметром при старте акции.
        :param secret: секретный ключ, доступный в интерфейсе тестирования рекламной акции.
        :param comment: комментарий

        :return: При успешном завершении оффера будет возвращен объект, содержащий следующие поля:   limit —
            ограничение, установленное у текущего оффера;  spent — количество потраченных на акцию голосов;  cost —
            стоимость одной выполненной акции;  test_mode — режим транзакции (1 — тестовый, 0 — реальный);  success —
            результат выполнения транзакции (всегда равно 1)
        """

        params = locals()
        method_name = self._base_method + 'complete'
        return self._call(method_name, params)

    def getStats(self, lead_id: str = None, secret: str = None, date_start: str = None, date_end: str = None) -> dict:
        """
        Возвращает статистику по рекламной акции.

        :param lead_id: идентификатор рекламной акции, доступный в интерфейсе тестирования рекламных акций.
        :param secret: секретный ключ, доступный в интерфейсе тестирования рекламной акции.
        :param date_start: идентификатор дня, начиная с которого необходимо вернуть статистику в формате Y-m-d
            (8-и значное число). Например, 2011-09-17.
        :param date_end: идентификатор дня, до которого необходимо вернуть статистику в формате Y-m-d (8-и
            значное число). Например, 2011-09-19.

        :return: При успешном завершении оффера будет возвращен объект, содержащий следующие поля:   limit —
            ограничения в голосах на текущую рекламную акцию;  spent — количество голосов, уже потраченных на
            рекламную акцию;  cost — стоимость (в голосах) одного прохождения;  impressions — количество показов
            акций;  started — количество начатых акций;  completed — количество пройденных акций;  days — данное поле
            возвращается, только если переданы входные параметры date_start и date_end.    Параметр days Объект days
            содержит следующие поля:   impressions — показы;  started — начатые акции;  completed — законченные
            акции;  spent — потрачено голосов
        """

        params = locals()
        method_name = self._base_method + 'getStats'
        return self._call(method_name, params)

    def getUsers(self, offer_id: str = None, secret: str = None, offset: str = None, count: str = None,
                 status: str = None, reverse: str = None) -> dict:
        """
        Возвращает список последних действий пользователей по рекламной акции.

        :param offer_id: идентификатор рекламной акции.
        :param secret: секретный ключ, доступный в интерфейсе редактирования рекламной акции.
        :param offset: смещение необходимое для выборки определенного подмножества действий.
        :param count: количество действий, которые необходимо вернуть.
        :param status: тип действия:   0 — начало действия;  1 — завершения действия;  2 — действия по
            блокированию пользователей;  4 — начало действия в тестовом режиме;  5 — завершения действия в тестовом
            режиме.  Если параметр не задан, возвращаются все действия.
        :param reverse:   0 — сортировка в обратном хронологическом порядке;  1 — сортировка в прямом
            хронологическом порядке.  Если параметр не задан, то значение по умолчанию 0

        :return: После успешного выполнения возвращает массив объектов entry, каждый из которых содержит поля:
            uid — идентификатор пользователя;  aid — идентификатор приложения, из которого было выполнено действие;
            sid — идентификатор сессии;  date — время действия в формате unixtime;  start_date — время начала
            действия в формате unixtime для status = 1;  status — 0 - начало действия, 1 - завершение действия, 2 -
            блокирование пользователя;  test_mode — 0 - рабочий режим, 1 - тестовый режим;  comment — текст
            комментария
        """

        params = locals()
        method_name = self._base_method + 'getUsers'
        return self._call(method_name, params)

    def metricHit(self, data: str = None) -> dict:
        """
        Засчитывает событие метрики.

        :param data: Данные метрики, полученные в личном кабинете рекламной акции.

        :return: Возвращает объект, содержащий поля:   result - равен true в случае успеха, и false в обратном
            случае,  redirect_link - возвращается в случае, когда пользователя нужно перенаправить по указанной
            ссылке
        """

        params = locals()
        method_name = self._base_method + 'metricHit'
        return self._call(method_name, params)

    def start(self, lead_id: str = None, secret: str = None, uid: str = None, aid: str = None, test_mode: str = None,
              force: str = None) -> dict:
        """
        Создаёт новую сессию для прохождения рекламной акции для пользователя.

        :param lead_id: идентификатор рекламной акции, доступный в интерфейсе тестирования рекламных акций.
        :param secret: секретный ключ, доступный в интерфейсе редактирования рекламных акций.
        :param uid: идентификатор пользователя, для которого необходимо получить сессию рекламной акции.
        :param aid: идентификатор приложения, на счет которого будут зачислены голоса. Если 0, при завершении
            рекламной акции голоса будут зачислены на счет пользователя.
        :param test_mode: 1 - запустить рекламную акцию в тестовом режиме;  0 - запустить рекламную акцию в
            боевом режиме (рекламная акция должна быть одобрена).
        :param force: 1 - запустить рекламную акцию без проверок пользователя на фрод. Рекомендуется использовать
            только при выполнении оффлайн-офферов.

        :return: При успешном старте рекламной акции будет возвращен объект содержащий следующие поля:
            test_mode — режим транзакции (1 — тестовый, 0 — реальный);  vk_sid — сессия рекламной акции
        """

        params = locals()
        method_name = self._base_method + 'start'
        return self._call(method_name, params)

